@@ -219,5 +219,12 @@ class AuthenticationView(APIView):
         config.add_cornice_service(change_password)
 
 
-def includeme(config):
+def defaults(config, **kwargs):
+    base = globals()
+
+    AuthenticationView = kwargs.get('AuthenticationView', base['AuthenticationView'])
     AuthenticationView.defaults(config)
+
+
+def includeme(config):
+    defaults(config)
