@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2022 Lance Edgar
+#  Copyright © 2010-2023 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,11 +24,8 @@
 Tailbone Web API - Receiving Batches
 """
 
-from __future__ import unicode_literals, absolute_import
-
 import logging
 
-import six
 import humanize
 
 from rattail.db import model
@@ -64,10 +61,10 @@ class ReceivingBatchViews(APIBatchView):
         data = super(ReceivingBatchViews, self).normalize(batch)
 
         data['vendor_uuid'] = batch.vendor.uuid
-        data['vendor_display'] = six.text_type(batch.vendor)
+        data['vendor_display'] = str(batch.vendor)
 
         data['department_uuid'] = batch.department_uuid
-        data['department_display'] = six.text_type(batch.department) if batch.department else None
+        data['department_display'] = str(batch.department) if batch.department else None
 
         data['po_total'] = batch.po_total
         data['invoice_total'] = batch.invoice_total
@@ -115,7 +112,7 @@ class ReceivingBatchViews(APIBatchView):
 
     def eligible_purchases(self):
         uuid = self.request.params.get('vendor_uuid')
-        vendor = self.Session.query(model.Vendor).get(uuid) if uuid else None
+        vendor = self.Session.get(model.Vendor, uuid) if uuid else None
         if not vendor:
             return {'error': "Vendor not found"}
 
@@ -289,7 +286,7 @@ class ReceivingBatchRowViews(APIBatchRowView):
 
         data['product_uuid'] = row.product_uuid
         data['item_id'] = row.item_id
-        data['upc'] = six.text_type(row.upc)
+        data['upc'] = str(row.upc)
         data['upc_pretty'] = row.upc.pretty() if row.upc else None
         data['brand_name'] = row.brand_name
         data['description'] = row.description
@@ -415,7 +412,7 @@ class ReceivingBatchRowViews(APIBatchRowView):
             return {'error': "Form did not validate"}
 
         # fetch / validate row object
-        row = self.Session.query(model.PurchaseBatchRow).get(form.validated['row'])
+        row = self.Session.get(model.PurchaseBatchRow, form.validated['row'])
         if row is not self.get_object():
             return {'error': "Specified row does not match the route!"}
 
