@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2022 Lance Edgar
+#  Copyright © 2010-2023 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,12 +24,8 @@
 Tailbone Web API - Master View
 """
 
-from __future__ import unicode_literals, absolute_import
-
 import json
 
-import six
-
 from rattail.config import parse_bool
 from rattail.db.util import get_fieldnames
 
@@ -279,7 +275,7 @@ class APIMasterView(APIView):
         return self._fieldnames
 
     def normalize(self, obj):
-        data = {'_str': six.text_type(obj)}
+        data = {'_str': str(obj)}
 
         for field in self.get_fieldnames():
             data[field] = getattr(obj, field)
@@ -287,7 +283,7 @@ class APIMasterView(APIView):
         return data
 
     def _collection_get(self):
-        from sqlalchemy_filters import apply_filters, apply_sort, apply_pagination
+        from sa_filters import apply_filters, apply_sort, apply_pagination
 
         query = self.base_query()
         context = {}
@@ -343,7 +339,7 @@ class APIMasterView(APIView):
         if not uuid:
             uuid = self.request.matchdict['uuid']
 
-        obj = self.Session.query(self.get_model_class()).get(uuid)
+        obj = self.Session.get(self.get_model_class(), uuid)
         if obj:
             return obj
 
@@ -394,7 +390,7 @@ class APIMasterView(APIView):
         """
         if not uuid:
             uuid = self.request.matchdict['uuid']
-        obj = self.Session.query(self.get_model_class()).get(uuid)
+        obj = self.Session.get(self.get_model_class(), uuid)
         if not obj:
             raise self.notfound()
 
@@ -479,13 +475,16 @@ class APIMasterView(APIView):
         """
         obj = self.get_object()
 
-        filename = self.request.GET.get('filename', None)
-        if not filename:
-            raise self.notfound()
-        path = self.download_path(obj, filename)
+        # TODO: is this really needed?
+        # filename = self.request.GET.get('filename', None)
+        # if filename:
+        #     path = self.download_path(obj, filename)
+        #     return self.file_response(path, attachment=False)
 
-        response = self.file_response(path, attachment=False)
-        return response
+        return self.rawbytes_response(obj)
+
+    def rawbytes_response(self, obj):
+        raise NotImplementedError
 
     ##############################
     # autocomplete
