@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2022 Lance Edgar
+#  Copyright © 2010-2023 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,12 +24,9 @@
 Application Entry Point
 """
 
-from __future__ import unicode_literals, absolute_import
-
 import os
 import warnings
 
-import six
 import sqlalchemy as sa
 from sqlalchemy.orm import sessionmaker, scoped_session
 
@@ -148,6 +145,16 @@ def make_pyramid_config(settings, configure_csrf=True):
     config.include('pyramid_mako')
     config.include('pyramid_tm')
 
+    # TODO: this may be a good idea some day, if wanting to leverage
+    # deform resources for component JS?  cf. also base.mako template
+    # # override default script mapping for deform
+    # from deform import Field
+    # from deform.widget import ResourceRegistry, default_resources
+    # registry = ResourceRegistry(use_defaults=False)
+    # for key in default_resources:
+    #     registry.set_js_resources(key, None, {'js': []})
+    # Field.set_default_resource_registry(registry)
+
     # bring in the pyramid_retry logic, if available
     # TODO: pretty soon we can require this package, hopefully..
     try:
@@ -159,7 +166,7 @@ def make_pyramid_config(settings, configure_csrf=True):
 
     # fetch all tailbone providers
     providers = get_all_providers(rattail_config)
-    for provider in six.itervalues(providers):
+    for provider in providers.values():
 
         # configure DB sessions associated with transaction manager
         provider.configure_db_sessions(rattail_config, config)
@@ -177,6 +184,7 @@ def make_pyramid_config(settings, configure_csrf=True):
     # and some similar magic for certain master views
     config.add_directive('add_tailbone_index_page', 'tailbone.app.add_index_page')
     config.add_directive('add_tailbone_config_page', 'tailbone.app.add_config_page')
+    config.add_directive('add_tailbone_model_view', 'tailbone.app.add_model_view')
     config.add_directive('add_tailbone_view_supplement', 'tailbone.app.add_view_supplement')
 
     config.add_directive('add_tailbone_websocket', 'tailbone.app.add_websocket')
@@ -192,7 +200,7 @@ def add_websocket(config, name, view, attr=None):
         rattail_config = config.registry.settings['rattail_config']
         rattail_app = rattail_config.get_app()
 
-        if isinstance(view, six.string_types):
+        if isinstance(view, str):
             view_callable = rattail_app.load_object(view)
         else:
             view_callable = view
@@ -240,6 +248,25 @@ def add_config_page(config, route_name, label, permission):
     config.action(None, action)
 
 
+def add_model_view(config, model_name, label, route_prefix, permission_prefix):
+    """
+    Register a model view for the app.
+    """
+    def action():
+        all_views = config.get_settings().get('tailbone_model_views', {})
+
+        model_views = all_views.setdefault(model_name, [])
+        model_views.append({
+            'label': label,
+            'route_prefix': route_prefix,
+            'permission_prefix': permission_prefix,
+        })
+
+        config.add_settings({'tailbone_model_views': all_views})
+
+    config.action(None, action)
+
+
 def add_view_supplement(config, route_prefix, cls):
     """
     Register a master view supplement for the app.
@@ -258,7 +285,7 @@ def establish_theme(settings):
     settings['tailbone.theme'] = theme
 
     directories = settings['mako.directories']
-    if isinstance(directories, six.string_types):
+    if isinstance(directories, str):
         directories = parse_list(directories)
 
     path = get_theme_template_path(rattail_config)
