@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2022 Lance Edgar
+#  Copyright © 2010-2023 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,12 +24,9 @@
 Forms Core
 """
 
-from __future__ import unicode_literals, absolute_import
-
 import json
 import logging
 
-import six
 import sqlalchemy as sa
 from sqlalchemy import orm
 from sqlalchemy.ext.associationproxy import AssociationProxy, ASSOCIATION_PROXY
@@ -51,7 +48,9 @@ from webhelpers2.html import tags, HTML
 from tailbone.db import Session
 from tailbone.util import raw_datetime, get_form_data, render_markdown
 from . import types
-from .widgets import ReadonlyWidget, PlainDateWidget, JQueryDateWidget, JQueryTimeWidget
+from .widgets import (ReadonlyWidget, PlainDateWidget,
+                      JQueryDateWidget, JQueryTimeWidget,
+                      MultiFileUploadWidget)
 from tailbone.exceptions import TailboneJSONFieldError
 
 
@@ -336,7 +335,7 @@ class Form(object):
                  model_instance=None, model_class=None, appstruct=UNSPECIFIED, nodes={}, enums={}, labels={},
                  assume_local_times=False, renderers=None, renderer_kwargs={},
                  hidden={}, widgets={}, defaults={}, validators={}, required={}, helptext={}, focus_spec=None,
-                 action_url=None, cancel_url=None, use_buefy=None, component='tailbone-form',
+                 action_url=None, cancel_url=None, component='tailbone-form',
                  vuejs_field_converters={},
                  # TODO: ugh this is getting out hand!
                  can_edit_help=False, edit_help_url=None, route_prefix=None,
@@ -375,7 +374,6 @@ class Form(object):
         self.focus_spec = focus_spec
         self.action_url = action_url
         self.cancel_url = cancel_url
-        self.use_buefy = use_buefy
         self.component = component
         self.vuejs_field_converters = vuejs_field_converters or {}
         self.can_edit_help = can_edit_help
@@ -579,6 +577,10 @@ class Form(object):
             node = colander.SchemaNode(nodeinfo, **kwargs)
         self.nodes[key] = node
 
+        # must explicitly replace node, if we already have a schema
+        if self.schema:
+            self.schema[key] = node
+
     def set_type(self, key, type_, **kwargs):
         if type_ == 'datetime':
             self.set_renderer(key, self.render_datetime)
@@ -624,9 +626,18 @@ class Form(object):
             if 'required' in kwargs and not kwargs['required']:
                 kw['missing'] = colander.null
             self.set_node(key, colander.SchemaNode(deform.FileData(), **kw))
-            # must explicitly replace node, if we already have a schema
-            if self.schema:
-                self.schema[key] = self.nodes[key]
+        elif type_ == 'multi_file':
+            tmpstore = SessionFileUploadTempStore(self.request)
+            file_node = colander.SchemaNode(deform.FileData(),
+                                            name='upload')
+
+            kw = {'name': key,
+                  'title': self.get_label(key),
+                  'widget': MultiFileUploadWidget(tmpstore)}
+            # if 'required' in kwargs and not kwargs['required']:
+            #     kw['missing'] = colander.null
+            files_node = colander.SequenceSchema(file_node, **kw)
+            self.set_node(key, files_node)
         else:
             raise ValueError("unknown type for '{}' field: {}".format(key, type_))
 
@@ -743,10 +754,7 @@ class Form(object):
 
     def render(self, template=None, **kwargs):
         if not template:
-            if self.readonly and not self.use_buefy:
-                template = '/forms/form_readonly.mako'
-            else:
-                template = '/forms/form.mako'
+            template = '/forms/form.mako'
         context = kwargs
         context['form'] = self
         return render(template, context)
@@ -791,10 +799,7 @@ class Form(object):
 
     def render_deform(self, dform=None, template=None, **kwargs):
         if not template:
-            if self.use_buefy:
-                template = '/forms/deform_buefy.mako'
-            else:
-                template = '/forms/deform.mako'
+            template = '/forms/deform_buefy.mako'
 
         if dform is None:
             dform = self.make_deform_form()
@@ -814,11 +819,8 @@ class Form(object):
         context.setdefault('form_kwargs', {})
         # TODO: deprecate / remove the latter option here
         if self.auto_disable_save or self.auto_disable:
-            if self.use_buefy:
-                context['form_kwargs'].setdefault('ref', self.component_studly)
-                context['form_kwargs']['@submit'] = 'submit{}'.format(self.component_studly)
-            else:
-                context['form_kwargs']['class_'] = 'autodisable'
+            context['form_kwargs'].setdefault('ref', self.component_studly)
+            context['form_kwargs']['@submit'] = 'submit{}'.format(self.component_studly)
         if self.focus_spec:
             context['form_kwargs']['data-focus'] = self.focus_spec
         context['request'] = self.request
@@ -853,25 +855,33 @@ class Form(object):
             value = convert(field.cstruct)
             return json.dumps(value)
 
-        if isinstance(field.schema.typ, deform.FileData):
-            # TODO: we used to always/only return 'null' here but hopefully
-            # this also works, to show existing filename when present
-            if field.cstruct and field.cstruct['filename']:
-                return json.dumps({'name': field.cstruct['filename']})
-            return 'null'
-
         if isinstance(field.schema.typ, colander.Set):
             if field.cstruct is colander.null:
                 return '[]'
 
-        if field.cstruct is colander.null:
-            return 'null'
-
         try:
-            return json.dumps(field.cstruct)
+            return self.jsonify_value(field.cstruct)
         except Exception as error:
             raise TailboneJSONFieldError(field.name, error)
 
+    def jsonify_value(self, value):
+        """
+        Take a Python value and convert to JSON
+        """
+        if value is colander.null:
+            return 'null'
+
+        if isinstance(value, dfwidget.filedict):
+            # TODO: we used to always/only return 'null' here but hopefully
+            # this also works, to show existing filename when present
+            if value and value['filename']:
+                return json.dumps({'name': value['filename']})
+            return 'null'
+
+        app = self.request.rattail_config.get_app()
+        value = app.json_friendly(value)
+        return json.dumps(value)
+
     def get_error_messages(self, field):
         if field.error:
             return field.error.messages()
@@ -952,8 +962,7 @@ class Form(object):
             if self.readonly or fieldname in self.readonly_fields:
                 html = self.render_field_value(fieldname) or HTML.tag('span')
             elif field:
-                html = field.serialize(use_buefy=True,
-                                       **self.get_renderer_kwargs(fieldname))
+                html = field.serialize(**self.get_renderer_kwargs(fieldname))
                 html = HTML.literal(html)
 
             # may need a complex label
@@ -1041,7 +1050,7 @@ class Form(object):
         value = self.obtain_value(record, field_name)
         if value is None:
             return ""
-        return six.text_type(value)
+        return str(value)
 
     def render_datetime(self, record, field_name):
         value = self.obtain_value(record, field_name)
@@ -1076,7 +1085,7 @@ class Form(object):
                 return "(${:0,.2f})".format(0 - value)
             return "${:0,.2f}".format(value)
         except ValueError:
-            return six.text_type(value)
+            return str(value)
 
     def render_quantity(self, obj, field):
         value = self.obtain_value(obj, field)
@@ -1101,8 +1110,8 @@ class Form(object):
             return ""
         enum = self.enums.get(field_name)
         if enum and value in enum:
-            return six.text_type(enum[value])
-        return six.text_type(value)
+            return str(enum[value])
+        return str(value)
 
     def render_codeblock(self, record, field_name):
         value = self.obtain_value(record, field_name)
@@ -1170,8 +1179,8 @@ class Form(object):
                         controls[i][1] = 'true'
                     elif value is False:
                         controls[i][1] = 'false'
-                    elif not isinstance(value, six.string_types):
-                        controls[i][1] = six.text_type(value)
+                    elif not isinstance(value, str):
+                        controls[i][1] = str(value)
 
             dform = self.make_deform_form()
             try:
