@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2022 Lance Edgar
+#  Copyright © 2010-2023 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -453,10 +453,18 @@ class Grid(object):
         return pretty_boolean(value)
 
     def obtain_value(self, obj, column_name):
+        """
+        Try to obtain and return the value from the given object, for
+        the given column name.
+
+        :returns: The value, or ``None`` if no value was found.
+        """
         try:
             return obj[column_name]
+        except KeyError:
+            pass
         except TypeError:
-            return getattr(obj, column_name)
+            return getattr(obj, column_name, None)
 
     def render_currency(self, obj, column_name):
         value = self.obtain_value(obj, column_name)
