@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2022 Lance Edgar
+#  Copyright © 2010-2023 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -41,7 +41,8 @@ from webhelpers2.html.tags import *
 from tailbone.util import (csrf_token, get_csrf_token,
                            pretty_datetime, raw_datetime,
                            render_markdown,
-                           route_exists)
+                           route_exists,
+                           get_liburl)
 
 
 def pretty_date(date):
