@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2022 Lance Edgar
+#  Copyright © 2010-2023 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,8 +24,6 @@
 Event Subscribers
 """
 
-from __future__ import unicode_literals, absolute_import
-
 import six
 import json
 import datetime
@@ -40,10 +38,9 @@ from webhelpers2.html import tags
 import tailbone
 from tailbone import helpers
 from tailbone.db import Session
-from tailbone.config import (csrf_header_name, should_expose_websockets,
-                             get_buefy_version, get_buefy_0_8)
+from tailbone.config import csrf_header_name, should_expose_websockets
 from tailbone.menus import make_simple_menus
-from tailbone.util import should_use_buefy, get_global_search_options
+from tailbone.util import get_global_search_options
 
 
 def new_request(event):
@@ -77,7 +74,7 @@ def new_request(event):
         uuid = request.authenticated_userid
         if uuid:
             model = request.rattail_config.get_model()
-            user = Session.query(model.User).get(uuid)
+            user = Session.get(model.User, uuid)
             if user:
                 Session().set_continuum_user(user)
         return user
@@ -157,30 +154,20 @@ def before_render(event):
             renderer_globals['background_color'] = request.rattail_config.get(
                 'tailbone', 'background_color')
 
-        # buefy themes get some extra treatment
-        if should_use_buefy(request):
+        # TODO: remove this hack once nothing references it
+        renderer_globals['buefy_0_8'] = False
 
-            # declare vue.js and buefy versions to use.  the default
-            # values here are "quite conservative" as of this writing,
-            # perhaps too much so, but at least they should work fine.
-            renderer_globals['vue_version'] = request.rattail_config.get(
-                'tailbone', 'vue_version') or '2.6.10'
-            version = get_buefy_version(rattail_config)
-            renderer_globals['buefy_version'] = version
-            renderer_globals['buefy_0_8'] = get_buefy_0_8(rattail_config,
-                                                          version=version)
+        # maybe set custom stylesheet
+        css = None
+        if request.user:
+            css = request.rattail_config.get('tailbone.{}'.format(request.user.uuid),
+                                             'buefy_css')
+        if not css:
+            css = request.rattail_config.get('tailbone', 'theme.falafel.buefy_css')
+        renderer_globals['buefy_css'] = css
 
-            # maybe set custom stylesheet
-            css = None
-            if request.user:
-                css = request.rattail_config.get('tailbone.{}'.format(request.user.uuid),
-                                                 'buefy_css')
-            if not css:
-                css = request.rattail_config.get('tailbone', 'theme.falafel.buefy_css')
-            renderer_globals['buefy_css'] = css
-
-            # add global search data for quick access
-            renderer_globals['global_search_data'] = get_global_search_options(request)
+        # add global search data for quick access
+        renderer_globals['global_search_data'] = get_global_search_options(request)
 
         # here we globally declare widths for grid filter pseudo-columns
         widths = request.rattail_config.get('tailbone', 'grids.filters.column_widths')
