@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2022 Lance Edgar
+#  Copyright © 2010-2023 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,11 +24,8 @@
 Utilities
 """
 
-from __future__ import unicode_literals, absolute_import
-
 import datetime
 
-import six
 import pytz
 import humanize
 import logging
@@ -98,24 +95,92 @@ def get_global_search_options(request):
     return options
 
 
-def should_use_buefy(request):
+def get_libver(request, key, fallback=True, default_only=False):
     """
-    Returns a flag indicating whether or not the current theme supports (and
-    therefore should use) the Buefy JS library.
+    Return the appropriate URL for the library identified by ``key``.
     """
-    # first check theme-specific setting, if one has been defined
-    theme = request.registry.settings['tailbone.theme']
-    buefy = request.rattail_config.getbool('tailbone', 'themes.{}.use_buefy'.format(theme))
-    if buefy is not None:
-        return buefy
+    config = request.rattail_config
 
-    # TODO: should not hard-code this surely, but works for now...
-    if theme == 'falafel':
-        return True
+    if not default_only:
+        version = config.get('tailbone', 'libver.{}'.format(key))
+        if version:
+            return version
 
-    # TODO: probably should not use this fallback? it was the first setting
-    # i tested with, but is poorly named to say the least
-    return request.rattail_config.getbool('tailbone', 'grids.use_buefy', default=False)
+    if not fallback and not default_only:
+
+        if key == 'buefy':
+            version = config.get('tailbone', 'buefy_version')
+            if version:
+                return version
+
+        elif key == 'buefy.css':
+            version = get_libver(request, 'buefy', fallback=False)
+            if version:
+                return version
+
+        elif key == 'vue':
+            version = config.get('tailbone', 'vue_version')
+            if version:
+                return version
+
+        return
+
+    if key == 'buefy':
+        if not default_only:
+            version = config.get('tailbone', 'buefy_version')
+            if version:
+                return version
+        return 'latest'
+
+    elif key == 'buefy.css':
+        version = get_libver(request, 'buefy', default_only=default_only)
+        if version:
+            return version
+        return 'latest'
+
+    elif key == 'vue':
+        if not default_only:
+            version = config.get('tailbone', 'vue_version')
+            if version:
+                return version
+        return '2.6.14'
+
+    elif key == 'vue_resource':
+        return 'latest'
+
+    elif key == 'fontawesome':
+        return '5.3.1'
+
+
+def get_liburl(request, key, fallback=True):
+    """
+    Return the appropriate URL for the library identified by ``key``.
+    """
+    config = request.rattail_config
+
+    url = config.get('tailbone', 'liburl.{}'.format(key))
+    if url:
+        return url
+
+    if not fallback:
+        return
+
+    version = get_libver(request, key)
+
+    if key == 'buefy':
+        return 'https://unpkg.com/buefy@{}/dist/buefy.min.js'.format(version)
+
+    elif key == 'buefy.css':
+        return 'https://unpkg.com/buefy@{}/dist/buefy.min.css'.format(version)
+
+    elif key == 'vue':
+        return 'https://unpkg.com/vue@{}/dist/vue.min.js'.format(version)
+
+    elif key == 'vue_resource':
+        return 'https://cdn.jsdelivr.net/npm/vue-resource@{}'.format(version)
+
+    elif key == 'fontawesome':
+        return 'https://use.fontawesome.com/releases/v{}/js/all.js'.format(version)
 
 
 def pretty_datetime(config, value):
@@ -184,7 +249,7 @@ def raw_datetime(config, value, verbose=False, as_date=False):
         else:
             kwargs['c'] = value.strftime('%Y-%m-%d %I:%M:%S %p')
     else:
-        kwargs['c'] = six.text_type(value)
+        kwargs['c'] = str(value)
 
     time_diff = app.render_time_ago(time_ago, fallback=None)
     if time_diff is not None:
