@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2022 Lance Edgar
+#  Copyright © 2010-2023 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,8 +24,6 @@
 Auth Views
 """
 
-from __future__ import unicode_literals, absolute_import
-
 from rattail.db.auth import authenticate_user, set_user_password
 
 import colander
@@ -101,9 +99,7 @@ class AuthenticationView(View):
             self.request.session.flash("{} is already logged in".format(self.request.user), 'error')
             return self.redirect(referrer)
 
-        use_buefy = self.get_use_buefy()
-        form = forms.Form(schema=UserLogin(), request=self.request,
-                          use_buefy=use_buefy)
+        form = forms.Form(schema=UserLogin(), request=self.request)
         form.save_label = "Login"
         form.auto_disable_save = False
         form.auto_disable = False # TODO: deprecate / remove this
@@ -126,16 +122,22 @@ class AuthenticationView(View):
             'tailbone', 'main_image_url',
             default=self.request.static_url('tailbone:static/img/home_logo.png'))
 
-        context = {
+        # nb. hacky..but necessary, to add the refs, for autofocus
+        # (also add key handler, so ENTER acts like TAB)
+        dform = form.make_deform_form()
+        dform['username'].widget.attributes = {
+            'ref': 'username',
+            '@keydown.native': 'usernameKeydown',
+        }
+        dform['password'].widget.attributes = {'ref': 'password'}
+
+        return {
             'form': form,
             'referrer': referrer,
             'image_url': image_url,
-            'use_buefy': use_buefy,
+            'index_title': self.rattail_config.node_title(),
             'help_url': global_help_url(self.rattail_config),
         }
-        if use_buefy:
-            context['index_title'] = self.rattail_config.node_title()
-        return context
 
     def authenticate_user(self, username, password):
         app = self.get_rattail_app()
@@ -177,15 +179,14 @@ class AuthenticationView(View):
             self.request.session.flash("Cannot change password for user: {}".format(self.request.user))
             return self.redirect(self.request.get_referrer())
 
-        use_buefy = self.get_use_buefy()
         schema = ChangePassword().bind(user=self.request.user, request=self.request)
-        form = forms.Form(schema=schema, request=self.request, use_buefy=use_buefy)
+        form = forms.Form(schema=schema, request=self.request)
         if form.validate(newstyle=True):
             set_user_password(self.request.user, form.validated['new_password'])
             self.request.session.flash("Your password has been changed.")
             return self.redirect(self.request.get_referrer())
 
-        return {'form': form, 'use_buefy': use_buefy}
+        return {'form': form}
 
     def become_root(self):
         """
