@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2022 Lance Edgar
+#  Copyright © 2010-2023 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,8 +24,6 @@
 Base views for maintaining "new-style" batches.
 """
 
-from __future__ import unicode_literals, absolute_import
-
 import os
 import sys
 import json
@@ -34,10 +32,8 @@ import logging
 import socket
 import subprocess
 import tempfile
-from six import StringIO
 
 import json
-import six
 import markdown
 import sqlalchemy as sa
 from sqlalchemy import orm
@@ -172,7 +168,6 @@ class BatchMasterView(MasterView):
 
     def template_kwargs_view(self, **kwargs):
         kwargs = super(BatchMasterView, self).template_kwargs_view(**kwargs)
-        use_buefy = self.get_use_buefy()
         batch = kwargs['instance']
         kwargs['batch'] = batch
         kwargs['handler'] = self.handler
@@ -194,30 +189,22 @@ class BatchMasterView(MasterView):
 
         breakdown = self.make_status_breakdown(batch)
 
-        if use_buefy:
-            factory = self.get_grid_factory()
-            g = factory('batch_row_status_breakdown', [],
-                        columns=['title', 'count'])
-            g.set_click_handler('title', "autoFilterStatus(props.row)")
-            kwargs['status_breakdown_data'] = breakdown
-            kwargs['status_breakdown_grid'] = HTML.literal(
-                g.render_buefy_table_element(data_prop='statusBreakdownData',
-                                             empty_labels=True))
-
-        else:
-            kwargs['status_breakdown'] = [
-                (status['title'], status['count'])
-                for status in breakdown]
+        factory = self.get_grid_factory()
+        g = factory('batch_row_status_breakdown', [],
+                    columns=['title', 'count'])
+        g.set_click_handler('title', "autoFilterStatus(props.row)")
+        kwargs['status_breakdown_data'] = breakdown
+        kwargs['status_breakdown_grid'] = HTML.literal(
+            g.render_buefy_table_element(data_prop='statusBreakdownData',
+                                         empty_labels=True))
 
         return kwargs
 
     def make_upload_worksheet_form(self, batch):
         action_url = self.get_action_url('upload_worksheet', batch)
-        use_buefy = self.get_use_buefy()
         form = forms.Form(schema=UploadWorksheet(),
                           request=self.request,
                           action_url=action_url,
-                          use_buefy=use_buefy,
                           component='upload-worksheet-form')
         form.set_type('worksheet_file', 'file')
         # TODO: must set these to avoid some default Buefy code
@@ -248,7 +235,7 @@ class BatchMasterView(MasterView):
         Thread target for updating a batch from worksheet.
         """
         session = self.make_isolated_session()
-        batch = session.query(self.model_class).get(batch_uuid)
+        batch = session.get(self.model_class, batch_uuid)
         try:
             self.handler.update_from_worksheet(batch, path, progress=progress)
 
@@ -362,6 +349,7 @@ class BatchMasterView(MasterView):
             f.remove('params')
         else:
             f.set_readonly('params')
+            f.set_renderer('params', self.render_params)
 
         # created
         f.set_readonly('created')
@@ -419,12 +407,20 @@ class BatchMasterView(MasterView):
                 f.remove_fields('executed',
                                 'executed_by')
 
+    def render_params(self, batch, field):
+        params = self.get_visible_params(batch)
+        if not params:
+            return
+
+        return params
+
+    def get_visible_params(self, batch):
+        return dict(batch.params or {})
+
     def render_complete(self, batch, field):
-        permission_prefix = self.get_permission_prefix()
-        use_buefy = self.get_use_buefy()
         text = "Yes" if batch.complete else "No"
 
-        if batch.executed or not self.request.has_perm('{}.edit'.format(permission_prefix)):
+        if batch.executed or not self.has_perm('edit'):
             return text
 
         if batch.complete:
@@ -434,18 +430,15 @@ class BatchMasterView(MasterView):
             label = "Mark Complete"
             value = 'true'
 
-        kwargs = {}
-        if not use_buefy:
-            kwargs['class_'] = 'autodisable'
-        begin_form = tags.form(self.get_action_url('toggle_complete', batch), **kwargs)
+        url = self.get_action_url('toggle_complete', batch)
+        kwargs = {'@submit': 'togglingBatchComplete = true'}
+        begin_form = tags.form(url, **kwargs)
 
-        if use_buefy:
-            submit = HTML.tag('once-button',
-                              type='is-primary',
-                              native_type='submit',
-                              text=label)
-        else:
-            submit = tags.submit('submit', label)
+        label = HTML.literal(
+            '{{{{ togglingBatchComplete ? "Working, please wait..." : "{}" }}}}'.format(label))
+        submit = self.make_buefy_button(label, is_primary=True,
+                                        native_type='submit',
+                                        **{':disabled': 'togglingBatchComplete'})
 
         form = [
             begin_form,
@@ -455,23 +448,16 @@ class BatchMasterView(MasterView):
             tags.end_form(),
         ]
 
-        if use_buefy:
-            text = HTML.tag('div', class_='control', c=text)
-            form = HTML.tag('div', class_='control', c=form)
-            content = [
-                HTML.tag('nav', class_='level',
-                         c=[HTML.tag('div', class_='level-left', c=[
-                             text,
-                             HTML.literal(' &nbsp; &nbsp; '),
-                             form,
-                         ])]),
-            ]
-
-        else:
-            content = [
-                text,
-                HTML.literal(' &nbsp; '),
-            ] + form
+        text = HTML.tag('div', class_='control', c=text)
+        form = HTML.tag('div', class_='control', c=form)
+        content = [
+            HTML.tag('nav', class_='level',
+                     c=[HTML.tag('div', class_='level-left', c=[
+                         text,
+                         HTML.literal(' &nbsp; &nbsp; '),
+                         form,
+                     ])]),
+        ]
 
         return HTML.tag('div', c=content)
 
@@ -479,7 +465,7 @@ class BatchMasterView(MasterView):
         user = getattr(batch, field)
         if not user:
             return ""
-        title = six.text_type(user)
+        title = str(user)
         url = self.request.route_url('users.view', uuid=user.uuid)
         return tags.link_to(title, url)
 
@@ -501,7 +487,7 @@ class BatchMasterView(MasterView):
 
             # TODO: this needs work yet surely...why is this an issue?
             # treat 'filename' field specially, for some reason it can be a filedict?
-            if 'filename' in kwargs and not isinstance(kwargs['filename'], six.string_types):
+            if 'filename' in kwargs and not isinstance(kwargs['filename'], str):
                 kwargs['filename'] = '' # null not allowed
 
             # TODO: is this still necessary with colander?
@@ -515,11 +501,21 @@ class BatchMasterView(MasterView):
         return batch
 
     def process_uploads(self, batch, form, uploads):
-        for key, upload in six.iteritems(uploads):
+
+        def process(upload, key):
             self.handler.set_input_file(batch, upload['temp_path'], attr=key)
             os.remove(upload['temp_path'])
             os.rmdir(upload['tempdir'])
 
+        for key, upload in uploads.items():
+            if isinstance(upload, dict):
+                process(upload, key)
+            else:
+                uploads = upload
+                for upload in uploads:
+                    if isinstance(upload, dict):
+                        process(upload, key)
+
     def get_batch_kwargs(self, batch, **kwargs):
         """
         Return a kwargs dict for use with ``self.handler.make_batch()``, using
@@ -635,7 +631,7 @@ class BatchMasterView(MasterView):
         code = row.status_code
         if code is None:
             return ""
-        text = self.get_row_status_enum().get(code, six.text_type(code))
+        text = self.get_row_status_enum().get(code, str(code))
         if row.status_text:
             return HTML.tag('span', title=row.status_text, c=text)
         return text
@@ -684,16 +680,13 @@ class BatchMasterView(MasterView):
         if self.rows_creatable and not batch.executed and not batch.complete:
             permission_prefix = self.get_permission_prefix()
             if self.request.has_perm('{}.create_row'.format(permission_prefix)):
-                link = tags.link_to("Create a new {}".format(self.get_row_model_title()),
-                                    self.get_action_url('create_row', batch))
-                return HTML.tag('p', c=[link])
+                url = self.get_action_url('create_row', batch)
+                return self.make_buefy_button("New Row", url=url,
+                                              is_primary=True,
+                                              icon_left='plus')
 
     def make_batch_row_grid_tools(self, batch):
-        if self.get_use_buefy():
-            return
-        if self.rows_bulk_deletable and not batch.executed and self.request.has_perm('{}.delete_rows'.format(self.get_permission_prefix())):
-            url = self.request.route_url('{}.delete_rows'.format(self.get_route_prefix()), uuid=batch.uuid)
-            return HTML.tag('p', c=[tags.link_to("Delete all rows matching current search", url)])
+        pass
 
     def make_row_grid_kwargs(self, **kwargs):
         """
@@ -705,21 +698,19 @@ class BatchMasterView(MasterView):
         # TODO: most of this logic is copied from MasterView, should refactor/merge somehow...
         if 'main_actions' not in kwargs:
             actions = []
-            use_buefy = self.get_use_buefy()
 
             # view action
             if self.rows_viewable:
                 view = lambda r, i: self.get_row_action_url('view', r)
-                icon = 'eye' if use_buefy else 'zoomin'
-                actions.append(self.make_action('view', icon=icon, url=view))
+                actions.append(self.make_action('view', icon='eye', url=view))
 
             # edit and delete are NOT allowed after execution, or if batch is "complete"
             if not batch.executed and not batch.complete:
 
                 # edit action
                 if self.rows_editable and self.has_perm('edit_row'):
-                    icon = 'edit' if use_buefy else 'pencil'
-                    actions.append(self.make_action('edit', icon=icon, url=self.row_edit_action_url))
+                    actions.append(self.make_action('edit', icon='edit',
+                                                    url=self.row_edit_action_url))
 
                 # delete action
                 if self.rows_deletable and self.has_perm('delete_row'):
@@ -765,7 +756,7 @@ class BatchMasterView(MasterView):
         # nb. must make new session, separate from main thread
         session = app.make_session()
         batch = self.get_instance_for_key(key, session)
-        batch_str = six.text_type(batch)
+        batch_str = str(batch)
 
         try:
             # try to delete batch
@@ -841,7 +832,6 @@ class BatchMasterView(MasterView):
         """
         defaults = {}
         route_prefix = self.get_route_prefix()
-        use_buefy = self.get_use_buefy()
 
         schema = None
         if self.has_execution_options(batch):
@@ -863,13 +853,12 @@ class BatchMasterView(MasterView):
                         labels[field.name] = field.title
 
                     # auto-convert select widgets for buefy theme
-                    if use_buefy and isinstance(field.widget, forms.widgets.PlainSelectWidget):
+                    if isinstance(field.widget, forms.widgets.PlainSelectWidget):
                         field.widget = dfwidget.SelectWidget(values=field.widget.values)
 
         if not schema:
             schema = colander.Schema()
 
-        kwargs['use_buefy'] = use_buefy
         kwargs['component'] = 'execute-form'
         form = forms.Form(schema=schema, request=self.request, defaults=defaults, **kwargs)
         self.configure_execute_form(form)
@@ -1023,17 +1012,16 @@ class BatchMasterView(MasterView):
         data = json.dumps({
             'everything_complete': True,
         })
-        if six.PY3:
-            data = data.encode('utf_8')
+        data = data.encode('utf_8')
         cxn.send(data)
         cxn.send(suffix)
         cxn.close()
 
     def catchup_versions(self, port, batch_uuid, username, *models):
         with short_session() as s:
-            batch = s.query(self.model_class).get(batch_uuid)
+            batch = s.get(self.model_class, batch_uuid)
             batch_id = batch.id_str
-            description = six.text_type(batch)
+            description = str(batch)
 
         self.launch_subprocess(
             port=port, username=username,
@@ -1058,8 +1046,8 @@ class BatchMasterView(MasterView):
         """
         # mustn't use tailbone web session here
         session = RattailSession()
-        batch = session.query(self.model_class).get(batch_uuid)
-        user = session.query(model.User).get(user_uuid)
+        batch = session.get(self.model_class, batch_uuid)
+        user = session.get(model.User, user_uuid)
         try:
             self.handler.do_populate(batch, user, progress=progress)
             session.flush()
@@ -1115,8 +1103,8 @@ class BatchMasterView(MasterView):
         # rattail session here; can't use tailbone because it has web request
         # transaction binding etc.
         session = RattailSession()
-        batch = session.query(self.model_class).get(batch_uuid)
-        cognizer = session.query(model.User).get(user_uuid) if user_uuid else None
+        batch = session.get(self.model_class, batch_uuid)
+        cognizer = session.get(model.User, user_uuid) if user_uuid else None
         try:
             self.refresh_data(session, batch, cognizer, progress=progress)
             session.flush()
@@ -1169,7 +1157,7 @@ class BatchMasterView(MasterView):
         """
         session = RattailSession()
         batches = batches.with_session(session).all()
-        user = session.query(model.User).get(user_uuid)
+        user = session.get(model.User, user_uuid)
         try:
             self.handler.refresh_many(batches, user=user, progress=progress)
 
@@ -1309,7 +1297,7 @@ class BatchMasterView(MasterView):
         # transaction binding etc.
         session = RattailSession()
         batch = self.get_instance_for_key(key, session)
-        user = session.query(model.User).get(user_uuid)
+        user = session.get(model.User, user_uuid)
         try:
             result = self.handler.do_execute(batch, user=user, progress=progress, **kwargs)
 
@@ -1384,7 +1372,7 @@ class BatchMasterView(MasterView):
         """
         session = RattailSession()
         batches = batches.with_session(session).all()
-        user = session.query(model.User).get(user_uuid)
+        user = session.get(model.User, user_uuid)
         try:
             result = self.handler.execute_many(batches, user=user, progress=progress, **kwargs)
 
