@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2020 Lance Edgar
+#  Copyright © 2010-2023 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,8 +24,6 @@
 Views for importer batches
 """
 
-from __future__ import unicode_literals, absolute_import
-
 import sqlalchemy as sa
 
 from rattail.db import model
@@ -41,7 +39,6 @@ class ImporterBatchView(BatchMasterView):
     """
     model_class = model.ImporterBatch
     default_handler_spec = 'rattail.batch.importer:ImporterBatchHandler'
-    model_title_plural = "Import / Export Batches"
     route_prefix = 'batch.importer'
     url_prefix = '/batches/importer'
     template_prefix = '/batch/importer'
@@ -140,7 +137,6 @@ class ImporterBatchView(BatchMasterView):
 
     def configure_row_grid(self, g):
         super(ImporterBatchView, self).configure_row_grid(g)
-        use_buefy = self.get_use_buefy()
 
         def make_filter(field, **kwargs):
             column = getattr(self.current_row_table.c, field)
@@ -151,11 +147,8 @@ class ImporterBatchView(BatchMasterView):
 
         # for some reason we have to do this differently for Buefy?
         kwargs = {}
-        if not use_buefy:
-            kwargs['value_enum'] = self.enum.IMPORTER_BATCH_ROW_STATUS
         make_filter('status_code', label="Status", **kwargs)
-        if use_buefy:
-            g.filters['status_code'].set_choices(self.enum.IMPORTER_BATCH_ROW_STATUS)
+        g.filters['status_code'].set_choices(self.enum.IMPORTER_BATCH_ROW_STATUS)
 
         def make_sorter(field):
             column = getattr(self.current_row_table.c, field)
@@ -197,7 +190,7 @@ class ImporterBatchView(BatchMasterView):
 
     def get_parent(self, row):
         uuid = self.current_row_table.name
-        return self.Session.query(model.ImporterBatch).get(uuid)
+        return self.Session.get(model.ImporterBatch, uuid)
 
     def get_row_instance_title(self, row):
         if row.object_str:
@@ -287,6 +280,30 @@ class ImporterBatchView(BatchMasterView):
         delete_query.execute()
         return self.redirect(self.get_action_url('view', batch))
 
+    def get_row_xlsx_fields(self):
+        return [
+            'sequence',
+            'object_key',
+            'object_str',
+            'status',
+            'status_code',
+            'status_text',
+        ]
+
+    def get_row_xlsx_row(self, row, fields):
+        xlrow = super(ImporterBatchView, self).get_row_xlsx_row(row, fields)
+
+        xlrow['status'] = self.enum.IMPORTER_BATCH_ROW_STATUS[row.status_code]
+
+        return xlrow
+
+
+def defaults(config, **kwargs):
+    base = globals()
+
+    ImporterBatchView = kwargs.get('ImporterBatchView', base['ImporterBatchView'])
+    ImporterBatchView.defaults(config)
+
 
 def includeme(config):
-    ImporterBatchView.defaults(config)
+    defaults(config)
