@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2021 Lance Edgar
+#  Copyright © 2010-2023 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,14 +24,10 @@
 Views for inventory batches
 """
 
-from __future__ import unicode_literals, absolute_import
-
 import re
 import decimal
 import logging
 
-import six
-
 from rattail import pod
 from rattail.db import model
 from rattail.db.util import make_full_description
@@ -218,7 +214,7 @@ class InventoryBatchView(BatchMasterView):
         return super(InventoryBatchView, self).save_edit_row_form(form)
 
     def delete_row(self):
-        row = self.Session.query(model.InventoryBatchRow).get(self.request.matchdict['row_uuid'])
+        row = self.Session.get(model.InventoryBatchRow, self.request.matchdict['row_uuid'])
         if not row:
             raise self.notfound()
         batch = row.batch
@@ -236,38 +232,44 @@ class InventoryBatchView(BatchMasterView):
 
         schema = DesktopForm().bind(session=self.Session())
         form = forms.Form(schema=schema, request=self.request)
-        if form.validate(newstyle=True):
+        if self.request.method == 'POST':
+            if form.validate(newstyle=True):
 
-            product = self.Session.query(model.Product).get(form.validated['product'])
+                product = self.Session.get(model.Product, form.validated['product'])
 
-            row = None
-            if self.should_aggregate_products(batch):
-                row = self.find_row_for_product(batch, product)
-                if row:
+                row = None
+                if self.should_aggregate_products(batch):
+                    row = self.find_row_for_product(batch, product)
+                    if row:
+                        row.cases = form.validated['cases']
+                        row.units = form.validated['units']
+                        self.handler.refresh_row(row)
+
+                if not row:
+                    row = model.InventoryBatchRow()
+                    row.product = product
+                    row.upc = form.validated['upc']
+                    row.brand_name = form.validated['brand_name']
+                    row.description = form.validated['description']
+                    row.size = form.validated['size']
+                    row.case_quantity = form.validated['case_quantity']
                     row.cases = form.validated['cases']
                     row.units = form.validated['units']
-                    self.handler.refresh_row(row)
+                    self.handler.capture_current_units(row)
+                    self.handler.add_row(batch, row)
 
-            if not row:
-                row = model.InventoryBatchRow()
-                row.product = product
-                row.upc = form.validated['upc']
-                row.brand_name = form.validated['brand_name']
-                row.description = form.validated['description']
-                row.size = form.validated['size']
-                row.case_quantity = form.validated['case_quantity']
-                row.cases = form.validated['cases']
-                row.units = form.validated['units']
-                self.handler.capture_current_units(row)
-                self.handler.add_row(batch, row)
+                description = make_full_description(form.validated['brand_name'],
+                                                    form.validated['description'],
+                                                    form.validated['size'])
+                self.request.session.flash("{} cases, {} units: {} {}".format(
+                    form.validated['cases'] or 0, form.validated['units'] or 0,
+                    form.validated['upc'].pretty(), description))
+                return self.redirect(self.request.current_route_url())
 
-            description = make_full_description(form.validated['brand_name'],
-                                                form.validated['description'],
-                                                form.validated['size'])
-            self.request.session.flash("{} cases, {} units: {} {}".format(
-                form.validated['cases'] or 0, form.validated['units'] or 0,
-                form.validated['upc'].pretty(), description))
-            return self.redirect(self.request.current_route_url())
+            else:
+                dform = form.make_deform_form()
+                msg = "Form did not validate: {}".format(str(dform.error))
+                self.request.session.flash(msg, 'error')
 
         title = self.get_instance_title(batch)
         return self.render_to_response('desktop_form', {
@@ -338,7 +340,7 @@ class InventoryBatchView(BatchMasterView):
             upc = re.sub(r'\D', '', entry.strip())
             if upc:
                 upc = GPC(upc)
-                result['upc'] = six.text_type(upc)
+                result['upc'] = str(upc)
                 result['upc_pretty'] = upc.pretty()
                 result['image_url'] = pod.get_image_url(self.rattail_config, upc)
 
@@ -367,10 +369,10 @@ class InventoryBatchView(BatchMasterView):
         data = {}
         if product and (not product.deleted or self.request.has_perm('products.view_deleted')):
             data['uuid'] = product.uuid
-            data['upc'] = six.text_type(product.upc)
+            data['upc'] = str(product.upc)
             data['upc_pretty'] = product.upc.pretty()
             data['full_description'] = product.full_description
-            data['brand_name'] = six.text_type(product.brand or '')
+            data['brand_name'] = str(product.brand or '')
             data['description'] = product.description
             data['size'] = product.size
             data['case_quantity'] = 1 # default
@@ -513,7 +515,7 @@ class InventoryBatchView(BatchMasterView):
 def valid_product(node, kw):
     session = kw['session']
     def validate(node, value):
-        product = session.query(model.Product).get(value)
+        product = session.get(model.Product, value)
         if not product:
             raise colander.Invalid(node, "Product not found")
         return product.uuid
