@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2022 Lance Edgar
+#  Copyright © 2010-2023 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,12 +24,8 @@
 Views for maintaining vendor catalogs
 """
 
-from __future__ import unicode_literals, absolute_import
-
 import logging
 
-import six
-
 from rattail.db import model
 
 import colander
@@ -196,9 +192,6 @@ class VendorCatalogView(FileBatchMasterView):
             values = [(p.key, p.display) for p in parsers]
             if len(values) == 1:
                 f.set_default('parser_key', parsers[0].key)
-            use_buefy = self.get_use_buefy()
-            if not use_buefy:
-                values.insert(0, ('', "(please choose)"))
             f.set_widget('parser_key', dfwidget.SelectWidget(values=values))
         else:
             f.set_readonly('parser_key')
@@ -232,10 +225,10 @@ class VendorCatalogView(FileBatchMasterView):
                 vendor_display = ""
                 if self.request.method == 'POST':
                     if self.request.POST.get('vendor_uuid'):
-                        vendor = self.Session.query(model.Vendor).get(
-                            self.request.POST['vendor_uuid'])
+                        vendor = self.Session.get(model.Vendor,
+                                                  self.request.POST['vendor_uuid'])
                         if vendor:
-                            vendor_display = six.text_type(vendor)
+                            vendor_display = str(vendor)
                 f.set_widget('vendor_uuid',
                              forms.widgets.JQueryAutocompleteWidget(
                                  field_display=vendor_display,
@@ -275,35 +268,20 @@ class VendorCatalogView(FileBatchMasterView):
         return parser.display
 
     def template_kwargs_create(self, **kwargs):
-        use_buefy = self.get_use_buefy()
         app = self.get_rattail_app()
         vendor_handler = app.get_vendor_handler()
         parsers = self.get_parsers()
         parsers_data = {}
         for parser in parsers:
-            if use_buefy:
-                pdata = {'key': parser.key,
-                         'vendor_key': parser.vendor_key}
-                if parser.vendor_key:
-                    vendor = vendor_handler.get_vendor(self.Session(),
-                                                       parser.vendor_key)
-                    if vendor:
-                        pdata['vendor_uuid'] = vendor.uuid
-                        pdata['vendor_name'] = vendor.name
-                parsers_data[parser.key] = pdata
-            else:
-                if parser.vendor_key:
-                    vendor = vendor_handler.get_vendor(self.Session(),
-                                                       parser.vendor_key)
-                    if vendor:
-                        parser.vendormap_value = "{{uuid: '{}', name: '{}'}}".format(
-                            vendor.uuid, vendor.name.replace("'", "\\'"))
-                    else:
-                        log.warning("vendor '{}' not found for parser: {}".format(
-                            parser.vendor_key, parser.key))
-                        parser.vendormap_value = 'null'
-                else:
-                    parser.vendormap_value = 'null'
+            pdata = {'key': parser.key,
+                     'vendor_key': parser.vendor_key}
+            if parser.vendor_key:
+                vendor = vendor_handler.get_vendor(self.Session(),
+                                                   parser.vendor_key)
+                if vendor:
+                    pdata['vendor_uuid'] = vendor.uuid
+                    pdata['vendor_name'] = vendor.name
+            parsers_data[parser.key] = pdata
         kwargs['parsers'] = parsers
         kwargs['parsers_data'] = parsers_data
         return kwargs
