@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2022 Lance Edgar
+#  Copyright © 2010-2023 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,10 +24,7 @@
 Various common views
 """
 
-from __future__ import unicode_literals, absolute_import
-
 import os
-import six
 
 from rattail.batch import consume_batch_id
 from rattail.util import OrderedDict, simple_error, import_module_path
@@ -62,14 +59,11 @@ class CommonView(View):
             'tailbone', 'main_image_url',
             default=self.request.static_url('tailbone:static/img/home_logo.png'))
 
-        use_buefy = self.get_use_buefy()
         context = {
             'image_url': image_url,
-            'use_buefy': use_buefy,
+            'index_title': self.rattail_config.node_title(),
             'help_url': global_help_url(self.rattail_config),
         }
-        if use_buefy:
-            context['index_title'] = self.rattail_config.node_title()
 
         if self.expose_quickie_search:
             context['quickie'] = self.get_quickie_context()
@@ -83,12 +77,8 @@ class CommonView(View):
         with open(self.robots_txt_path, 'rt') as f:
             content = f.read()
         response = self.request.response
-        if six.PY3:
-            response.text = content
-            response.content_type = 'text/plain'
-        else:
-            response.body = content
-            response.content_type = b'text/plain'
+        response.text = content
+        response.content_type = 'text/plain'
         return response
 
     def get_project_title(self):
@@ -114,16 +104,12 @@ class CommonView(View):
         """
         Generic view to show "about project" info page.
         """
-        use_buefy = self.get_use_buefy()
-        context = {
+        return {
             'project_title': self.get_project_title(),
             'project_version': self.get_project_version(),
             'packages': self.get_packages(),
-            'use_buefy': use_buefy,
+            'index_title': self.rattail_config.node_title(),
         }
-        if use_buefy:
-            context['index_title'] = self.rattail_config.node_title()
-        return context
 
     def get_packages(self):
         """
@@ -177,7 +163,7 @@ class CommonView(View):
         if form.validate(newstyle=True):
             data = dict(form.validated)
             if data['user']:
-                data['user'] = Session.query(model.User).get(data['user'])
+                data['user'] = Session.get(model.User, data['user'])
                 data['user_url'] = self.request.route_url('users.view', uuid=data['user'].uuid)
             data['client_ip'] = self.request.client_addr
             app.send_email('user_feedback', data=data)
@@ -203,7 +189,6 @@ class CommonView(View):
         if not self.request.is_root:
             raise self.forbidden()
 
-        use_buefy = self.get_use_buefy()
         app = self.get_rattail_app()
         app_title = self.rattail_config.app_title()
         poser_handler = app.get_poser_handler()
@@ -253,7 +238,6 @@ class CommonView(View):
             poser_error = simple_error(error)
 
         return {
-            'use_buefy': use_buefy,
             'app_title': app_title,
             'index_title': app_title,
             'poser_dir': poser_dir,
