@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2022 Lance Edgar
+#  Copyright © 2010-2023 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,12 +24,9 @@
 Customer Order Views
 """
 
-from __future__ import unicode_literals, absolute_import
-
 import decimal
 import logging
 
-import six
 from sqlalchemy import orm
 
 from rattail.db import model
@@ -195,7 +192,7 @@ class CustomerOrderView(MasterView):
         person = order.person
         if not person:
             return ""
-        text = six.text_type(person)
+        text = str(person)
         url = self.request.route_url('people.view', uuid=person.uuid)
         return tags.link_to(text, url)
 
@@ -203,7 +200,7 @@ class CustomerOrderView(MasterView):
         pending = batch.pending_customer
         if not pending:
             return
-        text = six.text_type(pending)
+        text = str(pending)
         url = self.request.route_url('pending_customers.view', uuid=pending.uuid)
         return tags.link_to(text, url,
                             class_='has-background-warning')
@@ -275,7 +272,7 @@ class CustomerOrderView(MasterView):
 
     def render_row_status_code(self, item, field):
         text = self.enum.CUSTORDER_ITEM_STATUS.get(item.status_code,
-                                                   six.text_type(item.status_code))
+                                                   str(item.status_code))
         if item.status_text:
             return HTML.tag('span', title=item.status_text, c=[text])
         return text
@@ -293,6 +290,7 @@ class CustomerOrderView(MasterView):
         submits the order, at which point the batch is converted to a proper
         order.
         """
+        app = self.get_rattail_app()
         # TODO: deprecate / remove this
         self.handler = self.batch_handler
         batch = self.get_current_batch()
@@ -349,6 +347,10 @@ class CustomerOrderView(MasterView):
             'default_uom_choices': self.batch_handler.uom_choices_for_product(None),
             'default_uom': None,
             'allow_item_discounts': self.batch_handler.allow_item_discounts(),
+            'allow_item_discounts_if_on_sale': self.batch_handler.allow_item_discounts_if_on_sale(),
+            # nb. render quantity so that '10.0' => '10'
+            'default_item_discount': app.render_quantity(
+                self.batch_handler.get_default_item_discount()),
             'allow_past_item_reorder': self.batch_handler.allow_past_item_reorder(),
         })
 
@@ -440,7 +442,7 @@ class CustomerOrderView(MasterView):
         if not uuid:
             return {'error': "Must specify a customer UUID"}
 
-        customer = self.Session.query(model.Customer).get(uuid)
+        customer = self.Session.get(model.Customer, uuid)
         if not customer:
             return {'error': "Customer not found"}
 
@@ -467,14 +469,14 @@ class CustomerOrderView(MasterView):
 
         if self.batch_handler.new_order_requires_customer():
 
-            customer = self.Session.query(model.Customer).get(uuid)
+            customer = self.Session.get(model.Customer, uuid)
             if not customer:
                 return {'error': "Customer not found"}
             kwargs['customer'] = customer
 
         else:
 
-            person = self.Session.query(model.Person).get(uuid)
+            person = self.Session.get(model.Person, uuid)
             if not person:
                 return {'error': "Person not found"}
             kwargs['person'] = person
@@ -483,7 +485,7 @@ class CustomerOrderView(MasterView):
         try:
             self.batch_handler.assign_contact(batch, **kwargs)
         except ValueError as error:
-            return {'error': six.text_type(error)}
+            return {'error': str(error)}
 
         self.Session.flush()
         context = self.get_context_contact(batch)
@@ -585,7 +587,7 @@ class CustomerOrderView(MasterView):
             self.batch_handler.update_pending_customer(batch, self.request.user,
                                                        data)
         except Exception as error:
-            return {'error': six.text_type(error)}
+            return {'error': str(error)}
 
         self.Session.flush()
         context = self.get_context_contact(batch)
@@ -614,7 +616,7 @@ class CustomerOrderView(MasterView):
         if not uuid:
             return {'error': "Must specify a product UUID"}
 
-        product = self.Session.query(model.Product).get(uuid)
+        product = self.Session.get(model.Product, uuid)
         if not product:
             return {'error': "Product not found"}
 
@@ -630,12 +632,14 @@ class CustomerOrderView(MasterView):
         try:
             info = self.batch_handler.get_product_info(batch, product)
         except Exception as error:
-            return {'error': six.text_type(error)}
+            return {'error': str(error)}
         else:
             info['url'] = self.request.route_url('products.view', uuid=info['uuid'])
-            return info
+            app = self.get_rattail_app()
+            return app.json_friendly(info)
 
     def get_past_items(self, batch, data):
+        app = self.get_rattail_app()
         past_products = self.batch_handler.get_past_products(batch)
         past_items = []
 
@@ -646,6 +650,7 @@ class CustomerOrderView(MasterView):
                 # nb. handler may raise error if product is "unsupported"
                 pass
             else:
+                item = app.json_friendly(item)
                 past_items.append(item)
 
         return {'past_items': past_items}
@@ -653,7 +658,7 @@ class CustomerOrderView(MasterView):
     def normalize_batch(self, batch):
         return {
             'uuid': batch.uuid,
-            'total_price': six.text_type(batch.total_price or 0),
+            'total_price': str(batch.total_price or 0),
             'total_price_display': "${:0.2f}".format(batch.total_price or 0),
             'status_code': batch.status_code,
             'status_text': batch.status_text,
@@ -682,7 +687,7 @@ class CustomerOrderView(MasterView):
             'sequence': row.sequence,
             'item_entry': row.item_entry,
             'product_uuid': row.product_uuid,
-            'product_upc': six.text_type(row.product_upc or ''),
+            'product_upc': str(row.product_upc or ''),
             'product_item_id': row.product_item_id,
             'product_scancode': row.product_scancode,
             'product_upc_pretty': row.product_upc.pretty() if row.product_upc else None,
@@ -719,7 +724,7 @@ class CustomerOrderView(MasterView):
             data['unit_sale_price_display'] = app.render_currency(row.unit_sale_price)
         if row.sale_ends:
             sale_ends = app.localtime(row.sale_ends, from_utc=True).date()
-            data['sale_ends'] = six.text_type(sale_ends)
+            data['sale_ends'] = str(sale_ends)
             data['sale_ends_display'] = app.render_date(sale_ends)
 
         if row.unit_sale_price and row.unit_price == row.unit_sale_price:
@@ -740,7 +745,7 @@ class CustomerOrderView(MasterView):
             pending = row.pending_product
             data['pending_product'] = {
                 'uuid': pending.uuid,
-                'upc': six.text_type(pending.upc) if pending.upc is not None else None,
+                'upc': str(pending.upc) if pending.upc is not None else None,
                 'item_id': pending.item_id,
                 'scancode': pending.scancode,
                 'brand_name': pending.brand_name,
@@ -818,7 +823,7 @@ class CustomerOrderView(MasterView):
             if not uuid:
                 return {'error': "Must specify a product UUID"}
 
-            product = self.Session.query(model.Product).get(uuid)
+            product = self.Session.get(model.Product, uuid)
             if not product:
                 return {'error': "Product not found"}
 
@@ -863,7 +868,7 @@ class CustomerOrderView(MasterView):
         if not uuid:
             return {'error': "Must specify a row UUID"}
 
-        row = self.Session.query(model.CustomerOrderBatchRow).get(uuid)
+        row = self.Session.get(model.CustomerOrderBatchRow, uuid)
         if not row:
             return {'error': "Row not found"}
 
@@ -880,7 +885,7 @@ class CustomerOrderView(MasterView):
             if not uuid:
                 return {'error': "Must specify a product UUID"}
 
-            product = self.Session.query(model.Product).get(uuid)
+            product = self.Session.get(model.Product, uuid)
             if not product:
                 return {'error': "Product not found"}
 
@@ -921,7 +926,7 @@ class CustomerOrderView(MasterView):
         if not uuid:
             return {'error': "Must specify a row UUID"}
 
-        row = self.Session.query(model.CustomerOrderBatchRow).get(uuid)
+        row = self.Session.get(model.CustomerOrderBatchRow, uuid)
         if not row:
             return {'error': "Row not found"}
 
@@ -987,6 +992,12 @@ class CustomerOrderView(MasterView):
             {'section': 'rattail.custorders',
              'option': 'allow_item_discounts',
              'type': bool},
+            {'section': 'rattail.custorders',
+             'option': 'allow_item_discounts_if_on_sale',
+             'type': bool},
+            {'section': 'rattail.custorders',
+             'option': 'default_item_discount',
+             'type': float},
             {'section': 'rattail.custorders',
              'option': 'allow_past_item_reorder',
              'type': bool},
