@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2022 Lance Edgar
+#  Copyright © 2010-2023 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,8 +24,6 @@
 View for running arbitrary import/export jobs
 """
 
-from __future__ import unicode_literals, absolute_import
-
 import getpass
 import socket
 import sys
@@ -34,7 +32,6 @@ import subprocess
 import time
 
 import json
-import six
 import sqlalchemy as sa
 
 from rattail.exceptions import ConfigurationError
@@ -222,7 +219,7 @@ class ImportingView(MasterView):
                 try:
                     return self.do_runjob(handler_info, form)
                 except Exception as error:
-                    self.request.session.flash(six.text_type(error), 'error')
+                    self.request.session.flash(str(error), 'error')
                     return self.redirect(self.request.current_route_url())
 
         return self.render_to_response('runjob', {
@@ -274,7 +271,6 @@ class ImportingView(MasterView):
         handler = handler_info['_handler']
         defaults = {
             'request': self.request,
-            'use_buefy': self.get_use_buefy(),
             'model_instance': handler,
             'cancel_url': self.request.route_url('{}.view'.format(route_prefix),
                                                  key=handler.get_key()),
@@ -411,8 +407,7 @@ And here is the output:
             data = json.dumps({
                 'everything_complete': True,
             })
-            if six.PY3:
-                data = data.encode('utf_8')
+            data = data.encode('utf_8')
             cxn.send(data)
             cxn.send(suffix)
             cxn.close()
@@ -627,11 +622,14 @@ class ImportHandlerSchema(colander.MappingSchema):
 
 class RunJobSchema(colander.MappingSchema):
 
-    handler_spec = colander.SchemaNode(colander.String())
+    handler_spec = colander.SchemaNode(colander.String(),
+                                       missing=colander.null)
     
-    host_title = colander.SchemaNode(colander.String())
+    host_title = colander.SchemaNode(colander.String(),
+                                       missing=colander.null)
 
-    local_title = colander.SchemaNode(colander.String())
+    local_title = colander.SchemaNode(colander.String(),
+                                       missing=colander.null)
 
     models = colander.SchemaNode(colander.List())
 
