@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2022 Lance Edgar
+#  Copyright © 2010-2023 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,10 +24,6 @@
 Message Views
 """
 
-from __future__ import unicode_literals, absolute_import
-
-import six
-
 from rattail.db import model
 from rattail.time import localtime
 
@@ -52,6 +48,7 @@ class MessageView(MasterView):
     checkboxes = True
     replying = False
     reply_header_sent_format = '%a %d %b %Y at %I:%M %p'
+    listable = False
 
     grid_columns = [
         'subject',
@@ -138,7 +135,7 @@ class MessageView(MasterView):
         sender = message.sender
         if sender is self.request.user:
             return 'you'
-        return six.text_type(sender)
+        return str(sender)
 
     def render_subject_bold(self, message, field):
         if not message.subject:
@@ -163,8 +160,6 @@ class MessageView(MasterView):
         if not recipients:
             return ""
 
-        use_buefy = self.get_use_buefy()
-
         # remove current user from displayed list, even if they're a recipient
         recips = [r for r in recipients
                   if r.recipient is not self.request.user]
@@ -181,23 +176,17 @@ class MessageView(MasterView):
         # client-side JS allowing the user to view all if they want
         max_display = 5
         if len(recips) > max_display:
-            if use_buefy:
-                basic = HTML.tag('span', c="{}, ".format(', '.join(recips[:max_display-1])))
-                more = tags.link_to("({} more)".format(len(recips[max_display-1:])), '#', **{
-                    'v-show': '!showingAllRecipients',
-                    '@click.prevent': 'showMoreRecipients()',
-                })
-                everyone = HTML.tag('span', c=', '.join(recips[max_display-1:]), **{
-                    'v-show': 'showingAllRecipients',
-                    '@click': 'hideMoreRecipients()',
-                    'class_': 'everyone',
-                })
-                return HTML.tag('div', c=[basic, more, everyone])
-            else:
-                basic = HTML.literal("{}, ".format(', '.join(recips[:max_display-1])))
-                more = tags.link_to("({} more)".format(len(recips[max_display-1:])), '#', class_='more')
-                everyone = HTML.tag('span', class_='everyone', c=', '.join(recips[max_display-1:]))
-                return basic + more + everyone
+            basic = HTML.tag('span', c="{}, ".format(', '.join(recips[:max_display-1])))
+            more = tags.link_to("({} more)".format(len(recips[max_display-1:])), '#', **{
+                'v-show': '!showingAllRecipients',
+                '@click.prevent': 'showMoreRecipients()',
+            })
+            everyone = HTML.tag('span', c=', '.join(recips[max_display-1:]), **{
+                'v-show': 'showingAllRecipients',
+                '@click': 'hideMoreRecipients()',
+                'class_': 'everyone',
+            })
+            return HTML.tag('div', c=[basic, more, everyone])
 
         # show the full list if there are few enough recipients for that
         return ', '.join(recips)
@@ -213,15 +202,9 @@ class MessageView(MasterView):
 
     def configure_form(self, f):
         super(MessageView, self).configure_form(f)
-        use_buefy = self.get_use_buefy()
 
         f.submit_label = "Send Message"
 
-        if not use_buefy:
-            # we have custom logic to disable submit button
-            f.auto_disable = False
-            f.auto_disable_save = False
-
         # TODO: A fair amount of this still seems hacky...
 
         f.set_renderer('sender', self.render_sender)
@@ -234,13 +217,12 @@ class MessageView(MasterView):
         f.set_label('recipients', "To")
 
         # subject
-        if use_buefy:
-            f.set_renderer('subject', self.render_subject_bold)
-            if self.creating:
-                f.set_widget('subject', dfwidget.TextInputWidget(
-                    placeholder="please enter a subject",
-                    autocomplete='off'))
-                f.set_required('subject')
+        f.set_renderer('subject', self.render_subject_bold)
+        if self.creating:
+            f.set_widget('subject', dfwidget.TextInputWidget(
+                placeholder="please enter a subject",
+                autocomplete='off'))
+            f.set_required('subject')
 
         # body
         f.set_widget('body', dfwidget.TextAreaWidget(cols=50, rows=15))
@@ -252,10 +234,7 @@ class MessageView(MasterView):
             f.insert_after('recipients', 'set_recipients')
             f.remove('recipients')
             f.set_node('set_recipients', colander.SchemaNode(colander.Set()))
-            if use_buefy:
-                f.set_widget('set_recipients', RecipientsWidgetBuefy())
-            else:
-                f.set_widget('set_recipients', RecipientsWidget())
+            f.set_widget('set_recipients', RecipientsWidgetBuefy())
             f.set_label('set_recipients', "To")
 
             if self.replying:
@@ -277,17 +256,11 @@ class MessageView(MasterView):
                     value = [r[0] for r in value]
                     if old_message.sender is not self.request.user and old_message.sender.active:
                         value.insert(0, old_message.sender_uuid)
-                    if use_buefy:
-                        f.set_default('set_recipients', value)
-                    else:
-                        f.set_default('set_recipients', ','.join(value))
+                    f.set_default('set_recipients', value)
 
                 # Just a normal reply, to sender only.
                 elif self.filter_reply_recipient(old_message.sender):
-                    if use_buefy:
-                        f.set_default('set_recipients', [old_message.sender.uuid])
-                    else:
-                        f.set_default('set_recipients', old_message.sender.uuid)
+                    f.set_default('set_recipients', [old_message.sender.uuid])
 
                 # TODO?
                 # # Set focus to message body instead of recipients, when replying.
@@ -306,7 +279,7 @@ class MessageView(MasterView):
                 message.sender = self.request.user
 
             for uuid in data['set_recipients']:
-                user = self.Session.query(model.User).get(uuid)
+                user = self.Session.get(model.User, uuid)
                 if user:
                     message.add_recipient(user, status=self.enum.MESSAGE_STATUS_INBOX)
 
@@ -346,11 +319,9 @@ class MessageView(MasterView):
                 return recipient
 
     def template_kwargs_create(self, **kwargs):
-        use_buefy = self.get_use_buefy()
 
         recips = self.get_available_recipients()
-        if use_buefy:
-            kwargs['recipient_display_map'] = recips
+        kwargs['recipient_display_map'] = recips
         recips = list(recips.items())
         recips.sort(key=self.recipient_sortkey)
         kwargs['available_recipients'] = recips
@@ -358,9 +329,8 @@ class MessageView(MasterView):
         if self.replying:
             kwargs['original_message'] = self.get_instance()
 
-        if use_buefy:
-            kwargs['index_url'] = None
-            kwargs['index_title'] = "New Message"
+        kwargs['index_url'] = None
+        kwargs['index_title'] = "New Message"
         return kwargs
 
     def recipient_sortkey(self, recip):
@@ -537,20 +507,6 @@ class SentView(MessageView):
                                                 default_active=True, default_verb='contains')
 
 
-class RecipientsWidget(dfwidget.TextInputWidget):
-
-    def deserialize(self, field, pstruct):
-        if pstruct is colander.null:
-            return []
-        elif not isinstance(pstruct, six.string_types):
-            raise colander.Invalid(field.schema, "Pstruct is not a string")
-        if self.strip:
-            pstruct = pstruct.strip()
-        if not pstruct:
-            return []
-        return pstruct.split(',')
-
-
 class RecipientsWidgetBuefy(dfwidget.Widget):
     """
     Custom "message recipients" widget, for use with Buefy / Vue.js themes.
@@ -560,7 +516,7 @@ class RecipientsWidgetBuefy(dfwidget.Widget):
     def deserialize(self, field, pstruct):
         if pstruct is colander.null:
             return colander.null
-        if not isinstance(pstruct, six.string_types):
+        if not isinstance(pstruct, str):
             raise colander.Invalid(field.schema, "Pstruct is not a string")
         if not pstruct:
             return colander.null
