@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2022 Lance Edgar
+#  Copyright © 2010-2023 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,12 +24,9 @@
 Person Views
 """
 
-from __future__ import unicode_literals, absolute_import
-
 import datetime
 import logging
 
-import six
 import sqlalchemy as sa
 from sqlalchemy import orm
 
@@ -165,22 +162,19 @@ class PersonView(MasterView):
                                     .filter(model.MergePeopleRequest.merged == None)\
                                     .first()
         if merge_request:
-            use_buefy = self.get_use_buefy()
-            if use_buefy:
-                return HTML.tag('span',
-                                class_='has-text-danger has-text-weight-bold',
-                                title="A merge has been requested for this person.",
-                                c="MR")
-            return "MR"
+            return HTML.tag('span',
+                            class_='has-text-danger has-text-weight-bold',
+                            title="A merge has been requested for this person.",
+                            c="MR")
 
     def get_instance(self):
         # TODO: I don't recall why this fallback check for a vendor contact
         # exists here, but leaving it intact for now.
         key = self.request.matchdict['uuid']
-        instance = self.Session.query(model.Person).get(key)
+        instance = self.Session.get(model.Person, key)
         if instance:
             return instance
-        instance = self.Session.query(model.VendorContact).get(key)
+        instance = self.Session.get(model.VendorContact, key)
         if instance:
             return instance.person
         raise HTTPNotFound
@@ -335,7 +329,7 @@ class PersonView(MasterView):
         employee = person.employee
         if not employee:
             return ""
-        text = six.text_type(employee)
+        text = str(employee)
         url = self.request.route_url('employees.view', uuid=employee.uuid)
         return tags.link_to(text, url)
 
@@ -346,7 +340,7 @@ class PersonView(MasterView):
         items = []
         for customer in customers:
             customer = customer.customer
-            text = six.text_type(customer)
+            text = str(customer)
             if customer.number:
                 text = "(#{}) {}".format(customer.number, text)
             elif customer.id:
@@ -361,7 +355,7 @@ class PersonView(MasterView):
             return ""
         items = []
         for member in members:
-            text = six.text_type(member)
+            text = str(member)
             if member.number:
                 text = "(#{}) {}".format(member.number, text)
             elif member.id:
@@ -371,7 +365,6 @@ class PersonView(MasterView):
         return HTML.tag('ul', c=items)
 
     def render_users(self, person, field):
-        use_buefy = self.get_use_buefy()
         users = person.users
         items = []
         for user in users:
@@ -381,11 +374,8 @@ class PersonView(MasterView):
         if items:
             return HTML.tag('ul', c=items)
         elif self.viewing and self.request.has_perm('users.create'):
-            if use_buefy:
-                return HTML.tag('b-button', type='is-primary', c="Make User",
-                                **{'@click': 'clickMakeUser()'})
-            else:
-                return HTML.tag('button', type='button', id='make-user', c="Make User")
+            return HTML.tag('b-button', type='is-primary', c="Make User",
+                            **{'@click': 'clickMakeUser()'})
         else:
             return ""
 
@@ -428,8 +418,7 @@ class PersonView(MasterView):
             'dynamic_content_title': self.get_context_content_title(person),
         }
 
-        use_buefy = self.get_use_buefy()
-        template = 'view_profile_buefy' if use_buefy else 'view_profile'
+        template = 'view_profile_buefy'
         return self.render_to_response(template, context)
 
     def get_customer_xref_buttons(self, person):
@@ -524,7 +513,7 @@ class PersonView(MasterView):
         return context
 
     def get_context_content_title(self, person):
-        return six.text_type(person)
+        return str(person)
 
     def get_context_address(self, address):
         context = {
@@ -534,7 +523,7 @@ class PersonView(MasterView):
             'city': address.city,
             'state': address.state,
             'zipcode': address.zipcode,
-            'display': six.text_type(address),
+            'display': str(address),
         }
 
         model = self.model
@@ -587,12 +576,12 @@ class PersonView(MasterView):
             'number': member.number,
             'id': member.id,
             'active': member.active,
-            'joined': six.text_type(member.joined) if member.joined else None,
-            'withdrew': six.text_type(member.withdrew) if member.withdrew else None,
+            'joined': str(member.joined) if member.joined else None,
+            'withdrew': str(member.withdrew) if member.withdrew else None,
             'customer_uuid': member.customer_uuid,
             'customer_name': member.customer.name if member.customer else None,
             'person_uuid': member.person_uuid,
-            'display': six.text_type(member),
+            'display': str(member),
             'person_display_name': member.person.display_name if member.person else None,
             'view_url': self.request.route_url('members.view', uuid=member.uuid),
             'view_profile_url': profile_url,
@@ -614,8 +603,8 @@ class PersonView(MasterView):
             for history in employee.sorted_history(reverse=True):
                 data.append({
                     'uuid': history.uuid,
-                    'start_date': six.text_type(history.start_date),
-                    'end_date': six.text_type(history.end_date or ''),
+                    'start_date': str(history.start_date),
+                    'end_date': str(history.end_date or ''),
                 })
         return data
 
@@ -688,7 +677,7 @@ class PersonView(MasterView):
         person = self.get_instance()
         data = dict(self.request.json_body)
 
-        phone = self.Session.query(model.PersonPhoneNumber).get(data['phone_uuid'])
+        phone = self.Session.get(model.PersonPhoneNumber, data['phone_uuid'])
         if not phone:
             return {'error': "Phone not found."}
 
@@ -719,7 +708,7 @@ class PersonView(MasterView):
         data = dict(self.request.json_body)
 
         # validate phone
-        phone = self.Session.query(model.PersonPhoneNumber).get(data['phone_uuid'])
+        phone = self.Session.get(model.PersonPhoneNumber, data['phone_uuid'])
         if not phone:
             return {'error': "Phone not found."}
         if phone not in person.phones:
@@ -742,7 +731,7 @@ class PersonView(MasterView):
         data = dict(self.request.json_body)
 
         # validate phone
-        phone = self.Session.query(model.PersonPhoneNumber).get(data['phone_uuid'])
+        phone = self.Session.get(model.PersonPhoneNumber, data['phone_uuid'])
         if not phone:
             return {'error': "Phone not found."}
         if phone not in person.phones:
@@ -803,7 +792,7 @@ class PersonView(MasterView):
         person = self.get_instance()
         data = dict(self.request.json_body)
 
-        email = self.Session.query(model.PersonEmailAddress).get(data['email_uuid'])
+        email = self.Session.get(model.PersonEmailAddress, data['email_uuid'])
         if not email:
             return {'error': "Email not found."}
 
@@ -830,7 +819,7 @@ class PersonView(MasterView):
         data = dict(self.request.json_body)
 
         # validate email
-        email = self.Session.query(model.PersonEmailAddress).get(data['email_uuid'])
+        email = self.Session.get(model.PersonEmailAddress, data['email_uuid'])
         if not email:
             return {'error': "Email not found."}
         if email not in person.emails:
@@ -854,7 +843,7 @@ class PersonView(MasterView):
         data = dict(self.request.json_body)
 
         # validate email
-        email = self.Session.query(model.PersonEmailAddress).get(data['email_uuid'])
+        email = self.Session.get(model.PersonEmailAddress, data['email_uuid'])
         if not email:
             return {'error': "Email not found."}
         if email not in person.emails:
@@ -911,7 +900,7 @@ class PersonView(MasterView):
             'success': True,
             'employee': self.get_context_employee(employee),
             'employee_view_url': self.request.route_url('employees.view', uuid=employee.uuid),
-            'start_date': six.text_type(start_date),
+            'start_date': str(start_date),
             'employee_history_data': self.get_context_employee_history(employee),
             'dynamic_content_title': self.get_context_content_title(person),
         }
@@ -942,7 +931,7 @@ class PersonView(MasterView):
             'success': True,
             'employee': self.get_context_employee(employee),
             'employee_view_url': self.request.route_url('employees.view', uuid=employee.uuid),
-            'end_date': six.text_type(end_date),
+            'end_date': str(end_date),
             'employee_history_data': self.get_context_employee_history(employee),
             'dynamic_content_title': self.get_context_content_title(person),
         }
@@ -955,7 +944,7 @@ class PersonView(MasterView):
         employee = person.employee
 
         uuid = self.request.json_body['uuid']
-        history = self.Session.query(model.EmployeeHistory).get(uuid)
+        history = self.Session.get(model.EmployeeHistory, uuid)
         if not history or history not in employee.history:
             return {'error': "Must specify a valid Employee History record for this Person."}
 
@@ -975,8 +964,8 @@ class PersonView(MasterView):
         return {
             'success': True,
             'employee': self.get_context_employee(employee),
-            'start_date': six.text_type(current_history.start_date),
-            'end_date': six.text_type(current_history.end_date or ''),
+            'start_date': str(current_history.start_date),
+            'end_date': str(current_history.end_date or ''),
             'employee_history_data': self.get_context_employee_history(employee),
         }
 
@@ -1043,7 +1032,7 @@ class PersonView(MasterView):
             return self.profile_edit_note_failure(person, form)
 
     def update_note(self, person, form):
-        note = self.Session.query(model.PersonNote).get(form.validated['uuid'])
+        note = self.Session.get(model.PersonNote, form.validated['uuid'])
         note.subject = form.validated['note_subject']
         note.text = form.validated['note_text']
         return note
@@ -1065,7 +1054,7 @@ class PersonView(MasterView):
             return self.profile_delete_note_failure(person, form)
 
     def delete_note(self, person, form):
-        note = self.Session.query(model.PersonNote).get(form.validated['uuid'])
+        note = self.Session.get(model.PersonNote, form.validated['uuid'])
         self.Session.delete(note)
 
     def profile_delete_note_success(self, person):
@@ -1076,7 +1065,7 @@ class PersonView(MasterView):
 
     def make_user(self):
         uuid = self.request.POST['person_uuid']
-        person = self.Session.query(model.Person).get(uuid)
+        person = self.Session.get(model.Person, uuid)
         if not person:
             return self.notfound()
         if person.users:
@@ -1366,7 +1355,7 @@ def valid_note_uuid(node, kw):
     session = kw['session']
     person_uuid = kw['person_uuid']
     def validate(node, value):
-        note = session.query(model.PersonNote).get(value)
+        note = session.get(model.PersonNote, value)
         if not note:
             raise colander.Invalid(node, "Note not found")
         if note.person.uuid != person_uuid:
@@ -1436,15 +1425,15 @@ class MergePeopleRequestView(MasterView):
 
     def render_referenced_person_name(self, merge_request, field):
         uuid = getattr(merge_request, field)
-        person = self.Session.query(self.model.Person).get(uuid)
+        person = self.Session.get(self.model.Person, uuid)
         if person:
-            return six.text_type(person)
+            return str(person)
         return "(person not found)"
 
     def get_instance_title(self, merge_request):
         model = self.model
-        removing = self.Session.query(model.Person).get(merge_request.removing_uuid)
-        keeping = self.Session.query(model.Person).get(merge_request.keeping_uuid)
+        removing = self.Session.get(model.Person, merge_request.removing_uuid)
+        keeping = self.Session.get(model.Person, merge_request.keeping_uuid)
         return "{} -> {}".format(
             removing or "(not found)",
             keeping or "(not found)")
@@ -1457,9 +1446,9 @@ class MergePeopleRequestView(MasterView):
 
     def render_referenced_person(self, merge_request, field):
         uuid = getattr(merge_request, field)
-        person = self.Session.query(self.model.Person).get(uuid)
+        person = self.Session.get(self.model.Person, uuid)
         if person:
-            text = six.text_type(person)
+            text = str(person)
             url = self.request.route_url('people.view', uuid=person.uuid)
             return tags.link_to(text, url)
         return "(person not found)"
