@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2022 Lance Edgar
+#  Copyright © 2010-2023 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,12 +24,9 @@
 Product Views
 """
 
-from __future__ import unicode_literals, absolute_import
-
 import re
 import logging
 
-import six
 import humanize
 import sqlalchemy as sa
 from sqlalchemy import orm
@@ -212,7 +209,6 @@ class ProductView(MasterView):
         super(ProductView, self).configure_grid(g)
         app = self.get_rattail_app()
         model = self.model
-        use_buefy = self.get_use_buefy()
 
         def join_vendor(q):
             return q.outerjoin(self.ProductVendorCost,
@@ -257,9 +253,6 @@ class ProductView(MasterView):
         departments = self.get_departments()
         department_choices = OrderedDict([('', "(any)")]
                                          + [(d.uuid, d.name) for d in departments])
-        if not use_buefy:
-            department_choices = [tags.Option(name, uuid)
-                                  for uuid, name in six.iteritems(department_choices)]
         g.set_filter('department', model.Department.uuid,
                      value_enum=department_choices,
                      verbs=['equal', 'not_equal', 'is_null', 'is_not_null', 'is_any'],
@@ -378,12 +371,9 @@ class ProductView(MasterView):
         g.set_filter('report_code_name', model.ReportCode.name)
 
         if self.expose_label_printing and self.has_perm('print_labels'):
-            if use_buefy:
-                g.more_actions.append(self.make_action(
-                    'print_label', icon='print', url='#',
-                    click_handler='quickLabelPrint(props.row)'))
-            else:
-                g.more_actions.append(grids.GridAction('print_label', icon='print'))
+            g.more_actions.append(self.make_action(
+                'print_label', icon='print', url='#',
+                click_handler='quickLabelPrint(props.row)'))
 
         g.set_renderer('regular_price', self.render_price)
         g.set_renderer('on_hand', self.render_on_hand)
@@ -572,10 +562,7 @@ class ProductView(MasterView):
         if not self.has_perm('versions'):
             return text
 
-        if self.get_use_buefy():
-            kwargs = {'@click.prevent': 'showPriceHistory_{}()'.format(typ)}
-        else:
-            kwargs = {'id': 'view-{}-price-history'.format(typ)}
+        kwargs = {'@click.prevent': 'showPriceHistory_{}()'.format(typ)}
         history = tags.link_to("(view history)", '#', **kwargs)
         if not text:
             return history
@@ -815,16 +802,16 @@ class ProductView(MasterView):
 
         if 'upc' in data:
             if isinstance(data['upc'], GPC):
-                data['upc'] = six.text_type(data['upc'])
+                data['upc'] = str(data['upc'])
 
         return data
 
     def get_instance(self):
         key = self.request.matchdict['uuid']
-        product = self.Session.query(model.Product).get(key)
+        product = self.Session.get(model.Product, key)
         if product:
             return product
-        price = self.Session.query(model.ProductPrice).get(key)
+        price = self.Session.get(model.ProductPrice, key)
         if price:
             return price.product
         raise self.notfound()
@@ -969,11 +956,11 @@ class ProductView(MasterView):
                 brand_display = ""
                 if self.request.method == 'POST':
                     if self.request.POST.get('brand_uuid'):
-                        brand = self.Session.query(model.Brand).get(self.request.POST['brand_uuid'])
+                        brand = self.Session.get(model.Brand, self.request.POST['brand_uuid'])
                         if brand:
-                            brand_display = six.text_type(brand)
+                            brand_display = str(brand)
                 elif self.editing:
-                    brand_display = six.text_type(product.brand or '')
+                    brand_display = str(product.brand or '')
                 brands_url = self.request.route_url('brands.autocomplete')
                 f.set_widget('brand_uuid', forms.widgets.JQueryAutocompleteWidget(
                     field_display=brand_display, service_url=brands_url))
@@ -1139,11 +1126,11 @@ class ProductView(MasterView):
                 history['price'] = float(price)
                 history['price_display'] = app.render_currency(price)
             changed = localtime(self.rattail_config, history['changed'], from_utc=True)
-            history['changed'] = six.text_type(changed)
+            history['changed'] = str(changed)
             history['changed_display_html'] = raw_datetime(self.rattail_config, changed)
             user = history.pop('changed_by')
             history['changed_by_uuid'] = user.uuid if user else None
-            history['changed_by_display'] = six.text_type(user or "??")
+            history['changed_by_display'] = str(user or "??")
             jsdata.append(history)
         return jsdata
 
@@ -1165,18 +1152,17 @@ class ProductView(MasterView):
             else:
                 history['cost_display'] = None
             changed = localtime(self.rattail_config, history['changed'], from_utc=True)
-            history['changed'] = six.text_type(changed)
+            history['changed'] = str(changed)
             history['changed_display_html'] = raw_datetime(self.rattail_config, changed)
             user = history.pop('changed_by')
             history['changed_by_uuid'] = user.uuid
-            history['changed_by_display'] = six.text_type(user)
+            history['changed_by_display'] = str(user)
             jsdata.append(history)
         return jsdata
 
     def template_kwargs_view(self, **kwargs):
         kwargs = super(ProductView, self).template_kwargs_view(**kwargs)
         product = kwargs['instance']
-        use_buefy = self.get_use_buefy()
 
         kwargs['image_url'] = self.products_handler.get_image_url(product)
 
@@ -1184,10 +1170,7 @@ class ProductView(MasterView):
         if self.rattail_config.versioning_enabled() and self.has_perm('versions'):
 
             # regular price
-            if use_buefy:
-                data = []       # defer fetching until user asks for it
-            else:
-                data = self.get_regular_price_history(product)
+            data = []       # defer fetching until user asks for it
             grid = grids.Grid('products.regular_price_history', data,
                               request=self.request,
                               columns=[
@@ -1201,10 +1184,7 @@ class ProductView(MasterView):
             kwargs['regular_price_history_grid'] = grid
 
             # current price
-            if use_buefy:
-                data = []       # defer fetching until user asks for it
-            else:
-                data = self.get_current_price_history(product)
+            data = []       # defer fetching until user asks for it
             grid = grids.Grid('products.current_price_history', data,
                               request=self.request,
                               columns=[
@@ -1222,10 +1202,7 @@ class ProductView(MasterView):
             kwargs['current_price_history_grid'] = grid
 
             # suggested price
-            if use_buefy:
-                data = []       # defer fetching until user asks for it
-            else:
-                data = self.get_suggested_price_history(product)
+            data = []       # defer fetching until user asks for it
             grid = grids.Grid('products.suggested_price_history', data,
                               request=self.request,
                               columns=[
@@ -1239,10 +1216,7 @@ class ProductView(MasterView):
             kwargs['suggested_price_history_grid'] = grid
 
             # cost history
-            if use_buefy:
-                data = []       # defer fetching until user asks for it
-            else:
-                data = self.get_cost_history(product)
+            data = []       # defer fetching until user asks for it
             grid = grids.Grid('products.cost_history', data,
                               request=self.request,
                               columns=[
@@ -1264,9 +1238,8 @@ class ProductView(MasterView):
         kwargs['costs_label_code'] = "Order Code"
         kwargs['costs_label_case_size'] = "Case Size"
 
-        if use_buefy:
-            kwargs['vendor_sources'] = self.get_context_vendor_sources(product)
-            kwargs['lookup_codes'] = self.get_context_lookup_codes(product)
+        kwargs['vendor_sources'] = self.get_context_vendor_sources(product)
+        kwargs['lookup_codes'] = self.get_context_lookup_codes(product)
 
         kwargs['panel_fields'] = self.get_panel_fields(product)
 
@@ -1320,20 +1293,26 @@ class ProductView(MasterView):
     def get_context_vendor_sources(self, product):
         app = self.get_rattail_app()
         route_prefix = self.get_route_prefix()
+        units_only = self.products_handler.units_only()
+
+        columns = [
+            'preferred',
+            'vendor',
+            'vendor_item_code',
+            'case_size',
+            'case_cost',
+            'unit_cost',
+            'status',
+        ]
+        if units_only:
+            columns.remove('case_size')
+            columns.remove('case_cost')
 
         factory = self.get_grid_factory()
         g = factory(
             key='{}.vendor_sources'.format(route_prefix),
             data=[],
-            columns=[
-                'preferred',
-                'vendor',
-                'vendor_item_code',
-                'case_size',
-                'case_cost',
-                'unit_cost',
-                'status',
-            ],
+            columns=columns,
             labels={
                 'preferred': "Pref.",
                 'vendor_item_code': "Order Code",
@@ -1348,13 +1327,15 @@ class ProductView(MasterView):
                 'uuid': cost.uuid,
                 'preferred': "X" if cost.preference == 1 else None,
                 'vendor_item_code': cost.code,
-                'case_size': app.render_quantity(cost.case_size),
-                'case_cost': app.render_currency(cost.case_cost),
                 'unit_cost': app.render_currency(cost.unit_cost, scale=4),
                 'status': "discontinued" if cost.discontinued else "available",
             }
 
-            text = six.text_type(cost.vendor)
+            if not units_only:
+                source['case_size'] = app.render_quantity(cost.case_size)
+                source['case_cost'] = app.render_currency(cost.case_cost)
+
+            text = str(cost.vendor)
             if link_vendor:
                 url = self.request.route_url('vendors.view', uuid=cost.vendor.uuid)
                 source['vendor'] = tags.link_to(text, url)
@@ -1760,8 +1741,6 @@ class ProductView(MasterView):
         # TODO: how to properly detect image type?
         # content_type = 'image/png'
         content_type = 'image/jpeg'
-        if not six.PY3:
-            content_type = six.binary_type(content_type)
         self.request.response.content_type = content_type
         self.request.response.body = product.image.bytes
         return self.request.response
@@ -1772,12 +1751,12 @@ class ProductView(MasterView):
         model = self.model
 
         profile = self.request.params.get('profile')
-        profile = self.Session.query(model.LabelProfile).get(profile) if profile else None
+        profile = self.Session.get(model.LabelProfile, profile) if profile else None
         if not profile:
             return {'error': "Label profile not found"}
 
         product = self.request.params.get('product')
-        product = self.Session.query(model.Product).get(product) if product else None
+        product = self.Session.get(model.Product, product) if product else None
         if not product:
             return {'error': "Product not found"}
 
@@ -1794,7 +1773,7 @@ class ProductView(MasterView):
             printer.print_labels([({'product': product}, quantity)])
         except Exception as error:
             log.warning("error occurred while printing labels", exc_info=True)
-            return {'error': six.text_type(error)}
+            return {'error': str(error)}
         return {'ok': True}
 
     def search(self):
@@ -1915,14 +1894,14 @@ class ProductView(MasterView):
             if product and (not product.deleted or self.request.has_perm('products.view_deleted')):
                 data = {
                     'uuid': product.uuid,
-                    'upc': six.text_type(product.upc),
+                    'upc': str(product.upc),
                     'upc_pretty': product.upc.pretty(),
                     'full_description': product.full_description,
                     'image_url': pod.get_image_url(self.rattail_config, product.upc),
                 }
                 uuid = self.request.GET.get('with_vendor_cost')
                 if uuid:
-                    vendor = self.Session.query(model.Vendor).get(uuid)
+                    vendor = self.Session.get(model.Vendor, uuid)
                     if not vendor:
                         return {'error': "Vendor not found"}
                     cost = product.cost_for_vendor(vendor)
@@ -2089,7 +2068,7 @@ class ProductView(MasterView):
         Threat target for making a batch from current products query.
         """
         session = RattailSession()
-        user = session.query(model.User).get(user_uuid)
+        user = session.get(model.User, user_uuid)
         assert user
         params['created_by'] = user
         try:
@@ -2140,11 +2119,16 @@ class ProductView(MasterView):
             {'section': 'tailbone',
              'option': 'products.show_pod_image',
              'type': bool},
+            {'section': 'rattail.pod',
+             'option': 'pictures.gtin.root_url'},
 
             # handling
             {'section': 'rattail',
              'option': 'products.convert_type2_for_gpc_lookup',
              'type': bool},
+            {'section': 'rattail',
+             'option': 'products.units_only',
+             'type': bool},
 
             # labels
             {'section': 'tailbone',
@@ -2271,7 +2255,7 @@ class PendingProductView(MasterView):
         g.set_enum('status_code', self.enum.PENDING_PRODUCT_STATUS)
         g.filters['status_code'].default_active = True
         g.filters['status_code'].default_verb = 'not_equal'
-        g.filters['status_code'].default_value = six.text_type(self.enum.PENDING_PRODUCT_STATUS_RESOLVED)
+        g.filters['status_code'].default_value = str(self.enum.PENDING_PRODUCT_STATUS_RESOLVED)
 
         g.set_sort_defaults('created', 'desc')
 
@@ -2304,11 +2288,11 @@ class PendingProductView(MasterView):
             brand_display = ""
             if self.request.method == 'POST':
                 if self.request.POST.get('brand_uuid'):
-                    brand = self.Session.query(model.Brand).get(self.request.POST['brand_uuid'])
+                    brand = self.Session.get(model.Brand, self.request.POST['brand_uuid'])
                     if brand:
-                        brand_display = six.text_type(brand)
+                        brand_display = str(brand)
             elif self.editing:
-                brand_display = six.text_type(pending.brand or '')
+                brand_display = str(pending.brand or '')
             brands_url = self.request.route_url('brands.autocomplete')
             f.set_widget('brand_uuid', forms.widgets.JQueryAutocompleteWidget(
                 field_display=brand_display, service_url=brands_url))
@@ -2331,9 +2315,9 @@ class PendingProductView(MasterView):
                 vendor_display = ""
                 if self.request.method == 'POST':
                     if self.request.POST.get('vendor_uuid'):
-                        vendor = self.Session.query(model.Vendor).get(self.request.POST['vendor_uuid'])
+                        vendor = self.Session.get(model.Vendor, self.request.POST['vendor_uuid'])
                         if vendor:
-                            vendor_display = six.text_type(vendor)
+                            vendor_display = str(vendor)
                 f.set_widget('vendor_uuid', forms.widgets.JQueryAutocompleteWidget(
                     field_display=vendor_display,
                     service_url=self.request.route_url('vendors.autocomplete')))
@@ -2430,7 +2414,7 @@ class PendingProductView(MasterView):
         redirect = self.redirect(self.get_action_url('view', pending))
 
         uuid = self.request.POST['product_uuid']
-        product = self.Session.query(model.Product).get(uuid)
+        product = self.Session.get(model.Product, uuid)
         if not product:
             self.request.session.flash("Product not found!", 'error')
             return redirect
