@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2022 Lance Edgar
+#  Copyright © 2010-2023 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,8 +24,6 @@
 Project views
 """
 
-from __future__ import unicode_literals, absolute_import
-
 import os
 import zipfile
 # from collections import OrderedDict
@@ -160,7 +158,6 @@ class GenerateProjectView(View):
         return RattailProjectHandler(self.rattail_config)
 
     def __call__(self):
-        use_buefy = self.get_use_buefy()
 
         # choices = OrderedDict([
         #     ('has_db', {'prompt': "Does project need its own Rattail DB?",
@@ -183,8 +180,7 @@ class GenerateProjectView(View):
             schema = GenerateTailboneIntegrationProject
         else:
             schema = GenerateProject
-        form = forms.Form(schema=schema(), request=self.request,
-                          use_buefy=use_buefy)
+        form = forms.Form(schema=schema(), request=self.request)
         if form.validate(newstyle=True):
             zipped = self.generate_project(project_type, form)
             return self.file_response(zipped)
@@ -195,7 +191,6 @@ class GenerateProjectView(View):
             'index_title': "Generate Project",
             'handler': self.handler,
             # 'choices': choices,
-            'use_buefy': use_buefy,
         }
 
     def generate_project(self, project_type, form):
