@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2022 Lance Edgar
+#  Copyright © 2010-2023 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,10 +24,6 @@
 Base class for purchasing batch views
 """
 
-from __future__ import unicode_literals, absolute_import
-
-import six
-
 from rattail.db import model, api
 
 import colander
@@ -230,7 +226,6 @@ class PurchasingBatchView(BatchMasterView):
         batch = f.model_instance
         app = self.get_rattail_app()
         today = app.localtime().date()
-        use_buefy = self.get_use_buefy()
 
         # mode
         f.set_enum('mode', self.enum.PURCHASE_BATCH_MODE)
@@ -276,9 +271,9 @@ class PurchasingBatchView(BatchMasterView):
                 vendor_display = ""
                 if self.request.method == 'POST':
                     if self.request.POST.get('vendor_uuid'):
-                        vendor = self.Session.query(model.Vendor).get(self.request.POST['vendor_uuid'])
+                        vendor = self.Session.get(model.Vendor, self.request.POST['vendor_uuid'])
                         if vendor:
-                            vendor_display = six.text_type(vendor)
+                            vendor_display = str(vendor)
                 vendors_url = self.request.route_url('vendors.autocomplete')
                 f.set_widget('vendor_uuid', forms.widgets.JQueryAutocompleteWidget(
                     field_display=vendor_display, service_url=vendors_url))
@@ -309,16 +304,16 @@ class PurchasingBatchView(BatchMasterView):
                 buyer_display = ""
                 if self.request.method == 'POST':
                     if self.request.POST.get('buyer_uuid'):
-                        buyer = self.Session.query(model.Employee).get(self.request.POST['buyer_uuid'])
+                        buyer = self.Session.get(model.Employee, self.request.POST['buyer_uuid'])
                         if buyer:
-                            buyer_display = six.text_type(buyer)
+                            buyer_display = str(buyer)
                 elif self.creating:
                     buyer = self.request.user.employee
                     if buyer:
-                        buyer_display = six.text_type(buyer)
+                        buyer_display = str(buyer)
                         f.set_default('buyer_uuid', buyer.uuid)
                 elif self.editing:
-                    buyer_display = six.text_type(batch.buyer or '')
+                    buyer_display = str(batch.buyer or '')
                 buyers_url = self.request.route_url('employees.autocomplete')
                 f.set_widget('buyer_uuid', forms.widgets.JQueryAutocompleteWidget(
                     field_display=buyer_display, service_url=buyers_url))
@@ -336,8 +331,8 @@ class PurchasingBatchView(BatchMasterView):
             kwargs = {}
 
             if 'vendor_uuid' in self.request.matchdict:
-                vendor = self.Session.query(model.Vendor).get(
-                    self.request.matchdict['vendor_uuid'])
+                vendor = self.Session.get(model.Vendor,
+                                          self.request.matchdict['vendor_uuid'])
                 if vendor:
                     kwargs['vendor'] = vendor
 
@@ -346,11 +341,7 @@ class PurchasingBatchView(BatchMasterView):
             if len(parsers) == 1:
                 f.set_default('invoice_parser_key', parsers[0].key)
 
-            if use_buefy:
-                f.set_widget('invoice_parser_key', dfwidget.SelectWidget(values=parser_values))
-            else:
-                parser_values.insert(0, ('', "(please choose)"))
-                f.set_widget('invoice_parser_key', forms.widgets.JQuerySelectWidget(values=parser_values))
+            f.set_widget('invoice_parser_key', dfwidget.SelectWidget(values=parser_values))
         else:
             f.remove_field('invoice_parser_key')
 
@@ -406,7 +397,7 @@ class PurchasingBatchView(BatchMasterView):
 
     def valid_vendor_uuid(self, node, value):
         model = self.model
-        vendor = self.Session.query(model.Vendor).get(value)
+        vendor = self.Session.get(model.Vendor, value)
         if not vendor:
             raise colander.Invalid(node, "Invalid vendor selection")
 
@@ -422,7 +413,7 @@ class PurchasingBatchView(BatchMasterView):
         purchase = batch.purchase
         if not purchase:
             return ""
-        text = six.text_type(purchase)
+        text = str(purchase)
         url = self.request.route_url('purchases.view', uuid=purchase.uuid)
         return tags.link_to(text, url)
 
@@ -435,7 +426,7 @@ class PurchasingBatchView(BatchMasterView):
 
     def render_vendor_contact(self, batch, field):
         if batch.vendor.contact:
-            return six.text_type(batch.vendor.contact)
+            return str(batch.vendor.contact)
 
     def render_vendor_phone(self, batch, field):
         return self.get_vendor_phone_number(batch)
@@ -455,7 +446,7 @@ class PurchasingBatchView(BatchMasterView):
         employee = batch.buyer
         if not employee:
             return ""
-        text = six.text_type(employee)
+        text = str(employee)
         if self.request.has_perm('employees.view'):
             url = self.request.route_url('employees.view', uuid=employee.uuid)
             return tags.link_to(text, url)
@@ -484,7 +475,7 @@ class PurchasingBatchView(BatchMasterView):
 
     def get_buyer_values(self):
         buyers = self.get_buyers()
-        return [(b.uuid, six.text_type(b))
+        return [(b.uuid, str(b))
                 for b in buyers]
 
     def get_department_options(self):
@@ -504,7 +495,7 @@ class PurchasingBatchView(BatchMasterView):
     def eligible_purchases(self, vendor_uuid=None, mode=None):
         if not vendor_uuid:
             vendor_uuid = self.request.GET.get('vendor_uuid')
-        vendor = self.Session.query(model.Vendor).get(vendor_uuid) if vendor_uuid else None
+        vendor = self.Session.get(model.Vendor, vendor_uuid) if vendor_uuid else None
         if not vendor:
             return {'error': "Must specify a vendor."}
 
@@ -581,7 +572,7 @@ class PurchasingBatchView(BatchMasterView):
                                self.enum.PURCHASE_BATCH_MODE_COSTING):
             purchase = batch.purchase
             if not purchase and batch.purchase_uuid:
-                purchase = self.Session.query(model.Purchase).get(batch.purchase_uuid)
+                purchase = self.Session.get(model.Purchase, batch.purchase_uuid)
                 assert purchase
             if purchase:
                 kwargs['purchase'] = purchase
@@ -802,13 +793,12 @@ class PurchasingBatchView(BatchMasterView):
             return app.render_cases_units(cases, units)
 
     def make_row_credits_grid(self, row):
-        use_buefy = self.get_use_buefy()
         route_prefix = self.get_route_prefix()
         factory = self.get_grid_factory()
 
         g = factory(
             key='{}.row_credits'.format(route_prefix),
-            data=[] if use_buefy else row.credits,
+            data=[],
             columns=[
                 'credit_type',
                 'shorted',
@@ -837,17 +827,9 @@ class PurchasingBatchView(BatchMasterView):
         return g
 
     def render_row_credits(self, row, field):
-        use_buefy = self.get_use_buefy()
-        if not use_buefy and not row.credits:
-            return
-
         g = self.make_row_credits_grid(row)
-
-        if use_buefy:
-            return HTML.literal(
-                g.render_buefy_table_element(data_prop='rowData.credits'))
-        else:
-            return HTML.literal(g.render_grid())
+        return HTML.literal(
+            g.render_buefy_table_element(data_prop='rowData.credits'))
 
 #     def item_lookup(self, value, field=None):
 #         """
