@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2021 Lance Edgar
+#  Copyright © 2010-2022 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -107,5 +107,12 @@ class ReportCodeView(MasterView):
 ReportCodesView = ReportCodeView
 
 
-def includeme(config):
+def defaults(config, **kwargs):
+    base = globals()
+
+    ReportCodeView = kwargs.get('ReportCodeView', base['ReportCodeView'])
     ReportCodeView.defaults(config)
+
+
+def includeme(config):
+    defaults(config)
