@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2022 Lance Edgar
+#  Copyright © 2010-2023 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,16 +24,12 @@
 Reporting views
 """
 
-from __future__ import unicode_literals, absolute_import
-
 import calendar
 import json
 import re
 import datetime
 import logging
 
-import six
-
 import rattail
 from rattail.db import model, Session as RattailSession
 from rattail.files import resource_path
@@ -64,13 +60,13 @@ def get_upc(product):
     UPC formatter.  Strips PLUs to bare number, and adds "minus check digit"
     for non-PLU UPCs.
     """
-    upc = six.text_type(product.upc)
+    upc = str(product.upc)
     m = plu_upc_pattern.match(upc)
     if m:
-        return six.text_type(int(m.group(1)))
+        return str(int(m.group(1)))
     m = weighted_upc_pattern.match(upc)
     if m:
-        return six.text_type(int(m.group(1)))
+        return str(int(m.group(1)))
     return '{0}-{1}'.format(upc[:-1], upc[-1])
 
 
@@ -85,13 +81,13 @@ class OrderingWorksheet(View):
 
     def __call__(self):
         if self.request.params.get('vendor'):
-            vendor = Session.query(model.Vendor).get(self.request.params['vendor'])
+            vendor = Session.get(model.Vendor, self.request.params['vendor'])
             if vendor:
                 departments = []
                 uuids = self.request.params.get('departments')
                 if uuids:
                     for uuid in uuids.split(','):
-                        dept = Session.query(model.Department).get(uuid)
+                        dept = Session.get(model.Department, uuid)
                         if dept:
                             departments.append(dept)
                 preferred_only = self.request.params.get('preferred_only') == '1'
@@ -139,7 +135,8 @@ class OrderingWorksheet(View):
             time=now.strftime('%I:%M %p'),
             get_upc=self.upc_getter,
             rattail=rattail,
-            )
+            app=self.get_rattail_app(),
+        )
 
         template_path = resource_path(self.report_template_path)
         template = Template(filename=template_path)
@@ -267,6 +264,9 @@ class ReportOutputView(ExportMasterView):
     def render_report_type(self, output, field):
         type_key = getattr(output, field)
 
+        # just show type key by default
+        rendered = type_key
+
         # (try to) show link to poser report if applicable
         if type_key and type_key.startswith('poser_'):
             app = self.get_rattail_app()
@@ -276,10 +276,20 @@ class ReportOutputView(ExportMasterView):
             if not report.get('error'):
                 url = self.request.route_url('poser_reports.view',
                                              report_key=poser_key)
-                return tags.link_to(type_key, url)
+                rendered = tags.link_to(type_key, url)
 
-        # fallback to showing value as-is
-        return type_key
+        # add help button if report has a link
+        report = self.report_handler.get_report(type_key)
+        if report and report.help_url:
+            button = self.make_buefy_button("Help for this report",
+                                            url=report.help_url,
+                                            is_external=True,
+                                            icon_left='question-circle')
+            button = HTML.tag('div', class_='level-item', c=[button])
+            rendered = HTML.tag('div', class_='level-item', c=[rendered])
+            rendered = HTML.tag('div', class_='level-left', c=[rendered, button])
+
+        return rendered
 
     def render_params(self, report, field):
         params = report.params
@@ -299,11 +309,8 @@ class ReportOutputView(ExportMasterView):
             columns=['key', 'value'],
             labels={'key': "Name"},
         )
-        if self.get_use_buefy():
-            return HTML.literal(
-                g.render_buefy_table_element(data_prop='paramsData'))
-        else:
-            return HTML.literal(g.render_grid())
+        return HTML.literal(
+            g.render_buefy_table_element(data_prop='paramsData'))
 
     def get_params_context(self, report):
         params_data = []
@@ -318,8 +325,7 @@ class ReportOutputView(ExportMasterView):
         kwargs = super(ReportOutputView, self).template_kwargs_view(**kwargs)
         output = kwargs['instance']
 
-        if self.get_use_buefy():
-            kwargs['params_data'] = self.get_params_context(output)
+        kwargs['params_data'] = self.get_params_context(output)
 
         # build custom URL to re-build this report
         url = None
@@ -334,9 +340,8 @@ class ReportOutputView(ExportMasterView):
     def template_kwargs_delete(self, **kwargs):
         kwargs = super(ReportOutputView, self).template_kwargs_delete(**kwargs)
 
-        if self.get_use_buefy():
-            report = kwargs['instance']
-            kwargs['params_data'] = self.get_params_context(report)
+        report = kwargs['instance']
+        kwargs['params_data'] = self.get_params_context(report)
 
         return kwargs
 
@@ -345,8 +350,6 @@ class ReportOutputView(ExportMasterView):
         View which allows user to choose which type of report they wish to
         generate.
         """
-        use_buefy = self.get_use_buefy()
-
         # handler is responsible for determining which report types are valid
         reports = self.report_handler.get_reports()
         if isinstance(reports, OrderedDict):
@@ -356,7 +359,7 @@ class ReportOutputView(ExportMasterView):
 
         # make form to accept user choice of report type
         schema = NewReport().bind(valid_report_types=sorted_reports)
-        form = forms.Form(schema=schema, request=self.request, use_buefy=use_buefy)
+        form = forms.Form(schema=schema, request=self.request)
         form.submit_label = "Continue"
         form.cancel_url = self.request.route_url('report_output')
 
@@ -364,11 +367,8 @@ class ReportOutputView(ExportMasterView):
         # e.g. some for customers/membership, others for product movement etc.
         values = [(r.type_key, r.name) for r in reports.values()]
         values.sort(key=lambda r: r[1])
-        if use_buefy:
-            form.set_widget('report_type', forms.widgets.CustomSelectWidget(values=values))
-            form.widgets['report_type'].set_template_values(input_handler='reportTypeChanged')
-        else:
-            form.set_widget('report_type', forms.widgets.PlainSelectWidget(values=values, size=10))
+        form.set_widget('report_type', forms.widgets.CustomSelectWidget(values=values))
+        form.widgets['report_type'].set_template_values(input_handler='reportTypeChanged')
 
         # if form validates, that means user has chosen a report type, so we
         # just redirect to the appropriate "new report" page
@@ -395,7 +395,6 @@ class ReportOutputView(ExportMasterView):
         and redirects user to view the output.
         """
         app = self.get_rattail_app()
-        use_buefy = self.get_use_buefy()
         type_key = self.request.matchdict['type_key']
         report = self.report_handler.get_report(type_key)
         if not report:
@@ -435,8 +434,7 @@ class ReportOutputView(ExportMasterView):
 
             schema.add(node)
 
-        form = forms.Form(schema=schema, request=self.request,
-                          use_buefy=use_buefy, helptext=helptext)
+        form = forms.Form(schema=schema, request=self.request, helptext=helptext)
         form.submit_label = "Generate this Report"
         form.cancel_url = self.request.get_referrer(
             default=self.request.route_url('{}.create'.format(route_prefix)))
@@ -497,7 +495,7 @@ class ReportOutputView(ExportMasterView):
         object.
         """
         session = RattailSession()
-        user = session.query(model.User).get(user_uuid)
+        user = session.get(model.User, user_uuid)
         try:
             output = self.report_handler.generate_output(session, report, params, user, progress=progress)
 
@@ -623,8 +621,8 @@ class ProblemReportView(MasterView):
         reports = self.handler.get_all_problem_reports()
         organized = self.handler.organize_problem_reports(reports)
 
-        for system_key, reports in six.iteritems(organized):
-            for report in six.itervalues(reports):
+        for system_key, reports in organized.items():
+            for report in reports.values():
                 data.append(self.normalize(report))
 
         return data
@@ -727,12 +725,12 @@ class ProblemReportView(MasterView):
                              report['problem_key'])
 
         app.save_setting(session, 'rattail.problems.{}.enabled'.format(key),
-                         six.text_type(data['enabled']).lower())
+                         str(data['enabled']).lower())
 
         for i in range(7):
             daykey = 'day{}'.format(i)
             app.save_setting(session, 'rattail.problems.{}.{}'.format(key, daykey),
-                             six.text_type(data['days'][daykey]).lower())
+                             str(data['days'][daykey]).lower())
 
     def execute_instance(self, report_info, user, progress=None, **kwargs):
         report = report_info['_report']
