@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2022 Lance Edgar
+#  Copyright © 2010-2023 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,23 +24,170 @@
 Settings Views
 """
 
-from __future__ import unicode_literals, absolute_import
-
+import os
 import re
+import subprocess
+import sys
 
 import json
-import six
 
 from rattail.db import model
 from rattail.settings import Setting
-from rattail.util import import_module_path
+from rattail.util import import_module_path, OrderedDict
 
 import colander
-from webhelpers2.html import tags
 
 from tailbone import forms
 from tailbone.db import Session
 from tailbone.views import MasterView, View
+from tailbone.util import get_libver, get_liburl
+
+
+class AppInfoView(MasterView):
+    """
+    Master view for the overall app, to show/edit config etc.
+    """
+    route_prefix = 'appinfo'
+    model_key = 'UNUSED'
+    model_title = "UNUSED"
+    model_title_plural = "App Details"
+    creatable = False
+    viewable = False
+    editable = False
+    deletable = False
+    filterable = False
+    pageable = False
+    configurable = True
+
+    grid_columns = [
+        'name',
+        'version',
+        'editable_project_location',
+    ]
+
+    def get_index_title(self):
+        return "{} for {}".format(self.get_model_title_plural(),
+                                  self.rattail_config.app_title())
+
+    def get_data(self, session=None):
+        pip = os.path.join(sys.prefix, 'bin', 'pip')
+        output = subprocess.check_output([pip, 'list', '--format=json'])
+        data = json.loads(output.decode('utf_8').strip())
+
+        for pkg in data:
+            pkg.setdefault('editable_project_location', '')
+
+        return data
+
+    def configure_grid(self, g):
+        super(AppInfoView, self).configure_grid(g)
+
+        g.sorters['name'] = g.make_simple_sorter('name', foldcase=True)
+        g.set_sort_defaults('name')
+        g.set_searchable('name')
+
+        g.sorters['version'] = g.make_simple_sorter('version', foldcase=True)
+
+        g.sorters['editable_project_location'] = g.make_simple_sorter(
+            'editable_project_location', foldcase=True)
+        g.set_searchable('editable_project_location')
+
+    def template_kwargs_index(self, **kwargs):
+        kwargs = super(AppInfoView, self).template_kwargs_index(**kwargs)
+        kwargs['configure_button_title'] = "Configure App"
+        return kwargs
+
+    def configure_get_context(self, **kwargs):
+        context = super(AppInfoView, self).configure_get_context(**kwargs)
+
+        weblibs = OrderedDict([
+            ('vue', "Vue"),
+            ('vue_resource', "vue-resource"),
+            ('buefy', "Buefy"),
+            ('buefy.css', "Buefy CSS"),
+            ('fontawesome', "FontAwesome"),
+        ])
+
+        for key in weblibs:
+            title = weblibs[key]
+            weblibs[key] = {
+                'key': key,
+                'title': title,
+
+                # nb. these values are exactly as configured, and are
+                # used for editing the settings
+                'configured_version': get_libver(self.request, key, fallback=False),
+                'configured_url': get_liburl(self.request, key, fallback=False),
+
+                # these are for informational purposes only
+                'default_version': get_libver(self.request, key, default_only=True),
+                'live_url': get_liburl(self.request, key),
+            }
+
+        context['weblibs'] = list(weblibs.values())
+        return context
+
+    def configure_get_simple_settings(self):
+        return [
+
+            # basics
+            {'section': 'rattail',
+             'option': 'app_title'},
+            {'section': 'rattail',
+             'option': 'node_type'},
+            {'section': 'rattail',
+             'option': 'node_title'},
+            {'section': 'rattail',
+             'option': 'production',
+             'type': bool},
+            {'section': 'rattail',
+             'option': 'running_from_source',
+             'type': bool},
+            {'section': 'rattail',
+             'option': 'running_from_source.rootpkg'},
+
+            # display
+            {'section': 'tailbone',
+             'option': 'background_color'},
+
+            # grids
+            {'section': 'tailbone',
+             'option': 'grid.default_pagesize',
+             # TODO: seems like should enforce this, but validation is
+             # not setup yet
+             # 'type': int
+            },
+
+            # web libs
+            {'section': 'tailbone',
+             'option': 'libver.vue'},
+            {'section': 'tailbone',
+             'option': 'liburl.vue'},
+            {'section': 'tailbone',
+             'option': 'libver.vue_resource'},
+            {'section': 'tailbone',
+             'option': 'liburl.vue_resource'},
+            {'section': 'tailbone',
+             'option': 'libver.buefy'},
+            {'section': 'tailbone',
+             'option': 'liburl.buefy'},
+            {'section': 'tailbone',
+             'option': 'libver.buefy.css'},
+            {'section': 'tailbone',
+             'option': 'liburl.buefy.css'},
+            {'section': 'tailbone',
+             'option': 'libver.fontawesome'},
+            {'section': 'tailbone',
+             'option': 'liburl.fontawesome'},
+
+            # nb. these are no longer used (deprecated), but we keep
+            # them defined here so the tool auto-deletes them
+            {'section': 'tailbone',
+             'option': 'buefy_version'},
+            {'section': 'tailbone',
+             'option': 'vue_version'},
+
+        ]
 
 
 class SettingView(MasterView):
@@ -71,7 +218,7 @@ class SettingView(MasterView):
             f.set_validator('name', self.unique_name)
 
     def unique_name(self, node, value):
-        setting = self.Session.query(model.Setting).get(value)
+        setting = self.Session.get(model.Setting, value)
         if setting:
             raise colander.Invalid(node, "Setting name must be unique")
 
@@ -151,25 +298,18 @@ class AppSettingsView(View):
                 option['url'] = self.request.route_url(option['route'])
                 config_options.append(option)
 
-        use_buefy = self.get_use_buefy()
         context = {
             'index_title': "App Settings",
             'form': form,
             'dform': form.make_deform_form(),
             'groups': groups,
             'settings': settings,
-            'use_buefy': use_buefy,
             'config_options': config_options,
         }
-        if use_buefy:
-            context['buefy_data'] = self.get_buefy_data(form, groups, settings)
-            # TODO: this seems hacky, and probably only needed if theme changes?
-            if current_group == '(All)':
-                current_group = ''
-        else:
-            group_options = [tags.Option(group, group) for group in groups]
-            group_options.insert(0, tags.Option("(All)", "(All)"))
-            context['group_options'] = group_options
+        context['buefy_data'] = self.get_buefy_data(form, groups, settings)
+        # TODO: this seems hacky, and probably only needed if theme changes?
+        if current_group == '(All)':
+            current_group = ''
         context['current_group'] = current_group
         return context
 
@@ -296,7 +436,7 @@ class AppSettingsView(View):
                            for entry in value.split('\n')]
                 value = ', '.join(entries)
             else:
-                value = six.text_type(value)
+                value = str(value)
             app = self.get_rattail_app()
             app.save_setting(Session(), legacy_name, value)
 
@@ -322,6 +462,9 @@ class AppSettingsView(View):
 def defaults(config, **kwargs):
     base = globals()
 
+    AppInfoView = kwargs.get('AppInfoView', base['AppInfoView'])
+    AppInfoView.defaults(config)
+
     AppSettingsView = kwargs.get('AppSettingsView', base['AppSettingsView'])
     AppSettingsView.defaults(config)
 
