@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2022 Lance Edgar
+#  Copyright © 2010-2023 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,8 +24,6 @@
 Views for employee time sheets
 """
 
-from __future__ import unicode_literals, absolute_import
-
 import datetime
 
 from rattail.db import model
@@ -74,7 +72,7 @@ class TimeSheetView(BaseTimeSheetView):
             deleted = []
             for uuid, value in list(data['delete'].items()):
                 assert value == 'delete'
-                shift = Session.query(model.WorkedShift).get(uuid)
+                shift = Session.get(model.WorkedShift, uuid)
                 assert shift
                 Session.delete(shift)
                 deleted.append(uuid)
@@ -93,7 +91,7 @@ class TimeSheetView(BaseTimeSheetView):
                     Session.add(shift)
                     created[uuid] = shift
                 else:
-                    shift = Session.query(model.WorkedShift).get(uuid)
+                    shift = Session.get(model.WorkedShift, uuid)
                     assert shift
                     updated[uuid] = shift
 
