@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2022 Lance Edgar
+#  Copyright © 2010-2023 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -121,6 +121,14 @@ class TempmonApplianceView(MasterView):
         elif self.creating or self.editing:
             f.remove_field('probes')
 
+    def template_kwargs_view(self, **kwargs):
+        kwargs = super(TempmonApplianceView, self).template_kwargs_view(**kwargs)
+        appliance = kwargs['instance']
+
+        kwargs['probes_data'] = self.normalize_probes(appliance.probes)
+
+        return kwargs
+
     def unique_name(self, node, value):
         query = self.Session.query(tempmon.Appliance)\
                             .filter(tempmon.Appliance.name == value)
