@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2022 Lance Edgar
+#  Copyright © 2010-2023 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,15 +24,11 @@
 Tempmon "Dashboard" View
 """
 
-from __future__ import unicode_literals, absolute_import
-
 import datetime
 
 from rattail.time import localtime, make_utc
 from rattail_tempmon.db import model as tempmon
 
-from webhelpers2.html import tags
-
 from tailbone.views import View
 from tailbone.db import TempmonSession
 
@@ -44,13 +40,12 @@ class TempmonDashboardView(View):
     session_key = 'tempmon.dashboard.appliance_uuid'
 
     def dashboard(self):
-        use_buefy = self.get_use_buefy()
 
         if self.request.method == 'POST':
             appliance = None
             uuid = self.request.POST.get('appliance_uuid')
             if uuid:
-                appliance = TempmonSession.query(tempmon.Appliance).get(uuid)
+                appliance = TempmonSession.get(tempmon.Appliance, uuid)
                 if appliance:
                     self.request.session[self.session_key] = appliance.uuid
             if not appliance:
@@ -71,29 +66,23 @@ class TempmonDashboardView(View):
                     self.request.session[self.session_key] = selected_uuid
 
         if not selected_appliance and selected_uuid:
-            selected_appliance = TempmonSession.query(tempmon.Appliance)\
-                                               .get(selected_uuid)
+            selected_appliance = TempmonSession.get(tempmon.Appliance, selected_uuid)
+
+        context = {
+            'index_url': self.request.route_url('tempmon.appliances'),
+            'index_title': "TempMon Appliances",
+            'appliance': selected_appliance,
+        }
 
         appliances = TempmonSession.query(tempmon.Appliance)\
                                    .order_by(tempmon.Appliance.name)\
                                    .all()
-        appliance_options = tags.Options([
-            tags.Option(appliance.name, appliance.uuid)
-            for appliance in appliances])
 
-        if use_buefy:
-            appliance_select = None
-            raise NotImplementedError
-        else:
-            appliance_select = tags.select('appliance_uuid', selected_uuid, appliance_options)
+        context['appliances_data'] = [{'uuid': a.uuid,
+                                       'name': a.name}
+                                      for a in appliances]
 
-        return {
-            'index_url': self.request.route_url('tempmon.appliances'),
-            'index_title': "TempMon Appliances",
-            'use_buefy': use_buefy,
-            'appliance_select': appliance_select,
-            'appliance': selected_appliance,
-        }
+        return context
 
     def readings(self):
 
@@ -101,7 +90,7 @@ class TempmonDashboardView(View):
         uuid = self.request.params.get('appliance_uuid')
         if not uuid:
             return {'error': "Must specify valid appliance_uuid"}
-        appliance = TempmonSession.query(tempmon.Appliance).get(uuid)
+        appliance = TempmonSession.get(tempmon.Appliance, uuid)
         if not appliance:
             return {'error': "Must specify valid appliance_uuid"}
 
