@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2021 Lance Edgar
+#  Copyright © 2010-2023 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -27,3 +27,7 @@ Trainwreck Views
 from __future__ import unicode_literals, absolute_import
 
 from .base import TransactionView
+
+
+def includeme(config):
+    config.include('tailbone.views.trainwreck.defaults')
