@@ -2,7 +2,7 @@
 ################################################################################
 #
 #  Rattail -- Retail Software Framework
-#  Copyright © 2010-2022 Lance Edgar
+#  Copyright © 2010-2023 Lance Edgar
 #
 #  This file is part of Rattail.
 #
@@ -24,9 +24,6 @@
 User Views
 """
 
-from __future__ import unicode_literals, absolute_import
-
-import six
 import sqlalchemy as sa
 from sqlalchemy import orm
 
@@ -168,7 +165,7 @@ class UserView(PrincipalMasterView):
         """
         if value:
             model = self.model
-            person = self.Session.query(model.Person).get(value)
+            person = self.Session.get(model.Person, value)
             if not person:
                 raise colander.Invalid(node, "Person not found (you must *select* a record)")
 
@@ -189,11 +186,11 @@ class UserView(PrincipalMasterView):
                 person_display = ""
                 if self.request.method == 'POST':
                     if self.request.POST.get('person_uuid'):
-                        person = self.Session.query(model.Person).get(self.request.POST['person_uuid'])
+                        person = self.Session.get(model.Person, self.request.POST['person_uuid'])
                         if person:
-                            person_display = six.text_type(person)
+                            person_display = str(person)
                 elif self.editing:
-                    person_display = six.text_type(user.person or '')
+                    person_display = str(user.person or '')
                 people_url = self.request.route_url('people.autocomplete')
                 f.set_widget('person_uuid', forms.widgets.JQueryAutocompleteWidget(
                     field_display=person_display, service_url=people_url))
@@ -224,7 +221,7 @@ class UserView(PrincipalMasterView):
                 f.remove_field('roles')
             else:
                 roles = self.get_possible_roles().all()
-                role_values = [(s.uuid, six.text_type(s)) for s in roles]
+                role_values = [(s.uuid, str(s)) for s in roles]
                 f.set_node('roles', colander.Set())
                 size = len(roles)
                 if size < 3:
@@ -358,7 +355,7 @@ class UserView(PrincipalMasterView):
         for uuid in old_roles:
             if uuid not in new_roles:
                 if self.request.is_root or uuid != admin.uuid:
-                    role = self.Session.query(model.Role).get(uuid)
+                    role = self.Session.get(model.Role, uuid)
                     user.roles.remove(role)
 
                     # also record a change to the role, for datasync.
@@ -373,7 +370,7 @@ class UserView(PrincipalMasterView):
         person = user.person
         if not person:
             return ""
-        text = six.text_type(person)
+        text = str(person)
         url = self.request.route_url('people.view', uuid=person.uuid)
         return tags.link_to(person, url)
 
@@ -383,7 +380,7 @@ class UserView(PrincipalMasterView):
         name = getattr(user, field[:-1], None)
         if not name:
             return ""
-        return six.text_type(name)
+        return str(name)
 
     def render_roles(self, user, field):
         roles = sorted(user.roles, key=lambda r: r.name)
